@@ -83,7 +83,7 @@ using namespace MessageComposer;
 
 ComposerViewBase::ComposerViewBase(QObject *parent, QWidget *parentGui)
     : QObject(parent)
-    , m_msg(KMime::Message::Ptr(new KMime::Message))
+    , m_msg(std::shared_ptr<KMime::Message>(new KMime::Message))
     , m_parentWidget(parentGui)
     , m_cryptoMessageFormat(Kleo::AutoFormat)
     , m_autoSaveInterval(60000) // default of 1 min
@@ -98,7 +98,7 @@ bool ComposerViewBase::isComposing() const
     return !m_composerJobs.isEmpty();
 }
 
-void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecryption)
+void ComposerViewBase::setMessage(const std::shared_ptr<KMime::Message> &msg, bool allowDecryption)
 {
     if (m_attachmentModel) {
         const auto attachments{m_attachmentModel->attachments()};
@@ -116,7 +116,8 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
             resultTooManyRecipients = m_recipientsEditor->setRecipientString(m_msg->cc()->mailboxes(), MessageComposer::Recipient::Cc);
         }
         if (!resultTooManyRecipients) {
-            resultTooManyRecipients = m_recipientsEditor->setRecipientString(m_msg->bcc()->mailboxes(), MessageComposer::Recipient::Bcc);
+            resultTooManyRecipients =
+                m_recipientsEditor->setRecipientString(m_msg->bcc(KMime::CreatePolicy::Create)->mailboxes(), MessageComposer::Recipient::Bcc);
         }
         if (!resultTooManyRecipients) {
             resultTooManyRecipients = m_recipientsEditor->setRecipientString(m_msg->replyTo()->mailboxes(), MessageComposer::Recipient::ReplyTo);
@@ -218,7 +219,7 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
         htmlContent.replace(QRegularExpression(u"<div\\s*id=\".*\">"_s), QStringLiteral("<div>"));
         m_editor->setHtml(htmlContent);
         Q_EMIT enableHtml();
-        collectImages(m_msg.data());
+        collectImages(m_msg.get());
     }
 
     if (auto hdr = m_msg->headerByType("X-KMail-CursorPos")) {
@@ -226,7 +227,7 @@ void ComposerViewBase::setMessage(const KMime::Message::Ptr &msg, bool allowDecr
     }
 }
 
-void ComposerViewBase::updateTemplate(const KMime::Message::Ptr &msg)
+void ComposerViewBase::updateTemplate(const std::shared_ptr<KMime::Message> &msg)
 {
     // First, we copy the message and then parse it to the object tree parser.
     // The otp gets the message text out of it, in textualContent(), and also decrypts
@@ -241,7 +242,7 @@ void ComposerViewBase::updateTemplate(const KMime::Message::Ptr &msg)
     if (!otp.htmlContent().isEmpty()) {
         m_editor->setHtml(otp.htmlContent());
         Q_EMIT enableHtml();
-        collectImages(msg.data());
+        collectImages(msg.get());
     } else {
         m_editor->setPlainText(otp.plainTextContent());
     }
@@ -254,27 +255,27 @@ void ComposerViewBase::updateTemplate(const KMime::Message::Ptr &msg)
 void ComposerViewBase::saveMailSettings()
 {
     const auto identity = currentIdentity();
-    auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Transport"));
+    auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-Transport");
     header->fromUnicodeString(QString::number(m_transport->currentTransportId()));
     m_msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Transport-Name"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Transport-Name");
     header->fromUnicodeString(m_transport->currentText());
     m_msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Fcc"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Fcc");
     header->fromUnicodeString(QString::number(m_fccCollection.id()));
     m_msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Identity"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Identity");
     header->fromUnicodeString(QString::number(identity.uoid()));
     m_msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Identity-Name"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Identity-Name");
     header->fromUnicodeString(identity.identityName());
     m_msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Dictionary"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Dictionary");
     header->fromUnicodeString(m_dictionary->currentDictionary());
     m_msg->setHeader(std::move(header));
 
@@ -283,14 +284,14 @@ void ComposerViewBase::saveMailSettings()
     if (m_editor->quotePrefixName().isEmpty()) {
         m_msg->removeHeader("X-KMail-QuotePrefix");
     } else {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-QuotePrefix"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-QuotePrefix");
         header->fromUnicodeString(m_editor->quotePrefixName());
         m_msg->setHeader(std::move(header));
     }
 
     if (m_editor->composerControler()->isFormattingUsed()) {
         qCDebug(MESSAGECOMPOSER_LOG) << "HTML mode";
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Markup"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-Markup");
         header->fromUnicodeString(u"true"_s);
         m_msg->setHeader(std::move(header));
     } else {
@@ -469,16 +470,16 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
                 unExpandedReplyTo << exp;
             }
         }
-        auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-UnExpanded-To"));
+        auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-UnExpanded-To");
         header->from7BitString(unExpandedTo.join(QLatin1StringView(", ")).toLatin1());
         m_msg->setHeader(std::move(header));
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-UnExpanded-CC"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-UnExpanded-CC");
         header->from7BitString(unExpandedCc.join(QLatin1StringView(", ")).toLatin1());
         m_msg->setHeader(std::move(header));
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-UnExpanded-BCC"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-UnExpanded-BCC");
         header->from7BitString(unExpandedBcc.join(QLatin1StringView(", ")).toLatin1());
         m_msg->setHeader(std::move(header));
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-UnExpanded-Reply-To"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-UnExpanded-Reply-To");
         header->from7BitString(unExpandedReplyTo.join(QLatin1StringView(", ")).toLatin1());
         m_msg->setHeader(std::move(header));
         autoresizeImage = false;
@@ -493,7 +494,7 @@ void ComposerViewBase::slotEmailAddressResolved(KJob *job)
     // if we aren't signing or encrypting, this just returns a single empty message
     if (m_neverEncrypt && mSaveIn != MessageComposer::MessageSender::SaveInNone && !mSendLaterInfo) {
         auto composerJob = new MessageComposer::ComposerJob;
-        composerJob->setNoCrypto(true);
+        composerJob->setNoCrypto(KMime::CreatePolicy::Create);
         m_composerJobs.append(composerJob);
     } else {
         bool wasCanceled = false;
@@ -798,7 +799,7 @@ QList<MessageComposer::ComposerJob *> ComposerViewBase::generateCryptoMessages(b
     signSomething = determineWhetherToSign(doSignCompletely, keyResolver.data(), signSomething, result, canceled);
     if (!result) {
         // TODO handle failure
-        qCDebug(MESSAGECOMPOSER_LOG) << "determineWhetherToSign: failed to resolve keys! oh noes";
+        qCDebug(MESSAGECOMPOSER_LOG) << "determineWhetherToSign: failed to resolve keys! oh no";
         if (!canceled) {
             Q_EMIT failed(i18n("Failed to resolve keys. Please report a bug."));
         } else {
@@ -812,7 +813,7 @@ QList<MessageComposer::ComposerJob *> ComposerViewBase::generateCryptoMessages(b
     encryptSomething = determineWhetherToEncrypt(doEncryptCompletely, keyResolver.data(), encryptSomething, signSomething, result, canceled);
     if (!result) {
         // TODO handle failure
-        qCDebug(MESSAGECOMPOSER_LOG) << "determineWhetherToEncrypt: failed to resolve keys! oh noes";
+        qCDebug(MESSAGECOMPOSER_LOG) << "determineWhetherToEncrypt: failed to resolve keys! oh no";
         if (!canceled) {
             Q_EMIT failed(i18n("Failed to resolve keys. Please report a bug."));
         } else {
@@ -845,7 +846,7 @@ QList<MessageComposer::ComposerJob *> ComposerViewBase::generateCryptoMessages(b
         return {};
     } else if (kpgpResult != ResolverResult::Ok) {
         // TODO handle failure
-        qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: failed to resolve keys! oh noes";
+        qCDebug(MESSAGECOMPOSER_LOG) << "resolveAllKeys: failed to resolve keys! oh no";
         Q_EMIT failed(i18n("Failed to resolve keys. Please report a bug."));
         return {};
     }
@@ -953,15 +954,15 @@ void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, Compose
     infoPart->setUserAgent(u"KMail"_s);
     infoPart->setUrgent(m_urgent);
 
-    if (auto inReplyTo = m_msg->inReplyTo(false)) {
+    if (auto inReplyTo = m_msg->inReplyTo(KMime::CreatePolicy::DontCreate)) {
         infoPart->setInReplyTo(inReplyTo->asUnicodeString());
     }
 
-    if (auto references = m_msg->references(false)) {
+    if (auto references = m_msg->references(KMime::CreatePolicy::DontCreate)) {
         infoPart->setReferences(references->asUnicodeString());
     }
 
-    KMime::Headers::Base::List extras;
+    QList<KMime::Headers::Base *> extras;
     if (auto hdr = m_msg->headerByType("X-KMail-SignatureActionEnabled")) {
         extras << hdr;
     }
@@ -983,7 +984,7 @@ void ComposerViewBase::fillInfoPart(MessageComposer::InfoPart *infoPart, Compose
     if (auto hdr = m_msg->headerByType("X-KMail-UnExpanded-Reply-To")) {
         extras << hdr;
     }
-    if (auto hdr = m_msg->organization(false)) {
+    if (auto hdr = m_msg->organization(KMime::CreatePolicy::DontCreate)) {
         extras << hdr;
     }
     if (auto hdr = m_msg->headerByType("X-KMail-Identity")) {
@@ -1071,22 +1072,22 @@ void ComposerViewBase::slotSendComposeResult(KJob *job)
     m_composerJobs.removeAll(composerJob);
 }
 
-void ComposerViewBase::saveRecentAddresses(const KMime::Message::Ptr &msg)
+void ComposerViewBase::saveRecentAddresses(const std::shared_ptr<KMime::Message> &msg)
 {
     KConfig *config = MessageComposer::MessageComposerSettings::self()->config();
-    if (auto to = msg->to(false)) {
+    if (auto to = msg->to(KMime::CreatePolicy::DontCreate)) {
         const auto toAddresses = to->mailboxes();
         for (const auto &address : toAddresses) {
             PimCommon::RecentAddresses::self(config)->add(address.prettyAddress());
         }
     }
-    if (auto cc = msg->cc(false)) {
+    if (auto cc = msg->cc(KMime::CreatePolicy::DontCreate)) {
         const auto ccAddresses = cc->mailboxes();
         for (const auto &address : ccAddresses) {
             PimCommon::RecentAddresses::self(config)->add(address.prettyAddress());
         }
     }
-    if (auto bcc = msg->bcc(false)) {
+    if (auto bcc = msg->bcc(KMime::CreatePolicy::DontCreate)) {
         const auto bccAddresses = bcc->mailboxes();
         for (const auto &address : bccAddresses) {
             PimCommon::RecentAddresses::self(config)->add(address.prettyAddress());
@@ -1094,7 +1095,7 @@ void ComposerViewBase::saveRecentAddresses(const KMime::Message::Ptr &msg)
     }
 }
 
-void ComposerViewBase::queueMessage(const KMime::Message::Ptr &message, MessageComposer::ComposerJob *composerJob)
+void ComposerViewBase::queueMessage(const std::shared_ptr<KMime::Message> &message, MessageComposer::ComposerJob *composerJob)
 {
     const MessageComposer::InfoPart *infoPart = composerJob->infoPart();
     auto qjob = new Akonadi::MessageQueueJob(this);
@@ -1170,7 +1171,7 @@ void ComposerViewBase::slotQueueResult(KJob *job)
     }
 
     if (m_pendingQueueJobs == 0) {
-        addFollowupReminder(qjob->message()->messageID(false)->asUnicodeString());
+        addFollowupReminder(qjob->message()->messageID(KMime::CreatePolicy::DontCreate)->asUnicodeString());
         Q_EMIT sentSuccessfully(-1);
     }
 }
@@ -1331,7 +1332,7 @@ void ComposerViewBase::slotAutoSaveComposeResult(KJob *job)
     m_composerJobs.removeAll(composerJob);
 }
 
-void ComposerViewBase::writeAutoSaveToDisk(const KMime::Message::Ptr &message)
+void ComposerViewBase::writeAutoSaveToDisk(const std::shared_ptr<KMime::Message> &message)
 {
     const QString autosavePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1StringView("/kmail2/autosave/");
     QDir().mkpath(autosavePath);
@@ -1373,11 +1374,11 @@ void ComposerViewBase::writeAutoSaveToDisk(const KMime::Message::Ptr &message)
         // No error occurred, the next error should be shown again
         m_autoSaveErrorShown = false;
     }
-    file.commit();
+
     message->clear();
 }
 
-void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageComposer::MessageSender::SaveIn saveIn)
+void ComposerViewBase::saveMessage(const std::shared_ptr<KMime::Message> &message, MessageComposer::MessageSender::SaveIn saveIn)
 {
     Akonadi::Collection target;
     const auto identity = currentIdentity();
@@ -1433,7 +1434,7 @@ void ComposerViewBase::saveMessage(const KMime::Message::Ptr &message, MessageCo
 void ComposerViewBase::slotSaveMessage(KJob *job)
 {
     Akonadi::Collection target;
-    auto item = job->property("Akonadi::Item").value<Akonadi::Item>();
+    const auto item = job->property("Akonadi::Item").value<Akonadi::Item>();
     if (job->error()) {
         target = defaultSpecialTarget();
     } else {
@@ -1522,26 +1523,29 @@ void ComposerViewBase::addAttachment(const QString &name, const QString &filenam
     }
 }
 
-void ComposerViewBase::addAttachmentPart(KMime::Content *partToAttach)
+void ComposerViewBase::addAttachmentPart(const KMime::Content *partToAttach)
 {
     MessageCore::AttachmentPart::Ptr part(new MessageCore::AttachmentPart);
-    if (partToAttach->contentType()->mimeType() == "multipart/digest" || partToAttach->contentType(false)->mimeType() == "message/rfc822") {
+    const auto ct = partToAttach->contentType();
+    if (ct && (ct->mimeType() == "multipart/digest" || ct->mimeType() == "message/rfc822")) {
         // if it is a digest or a full message, use the encodedContent() of the attachment,
         // which already has the proper headers
         part->setData(partToAttach->encodedContent());
     } else {
         part->setData(partToAttach->decodedBody());
     }
-    part->setMimeType(partToAttach->contentType(false)->mimeType());
-    if (auto cd = partToAttach->contentDescription(false)) {
+    if (ct) {
+        part->setMimeType(ct->mimeType());
+    }
+    if (auto cd = partToAttach->contentDescription()) {
         part->setDescription(cd->asUnicodeString());
     }
-    if (auto ct = partToAttach->contentType(false)) {
-        if (ct->hasParameter("name")) {
-            part->setName(ct->parameter("name"));
+    if (auto pct = partToAttach->contentType()) {
+        if (pct->hasParameter("name")) {
+            part->setName(pct->parameter("name"));
         }
     }
-    if (auto cd = partToAttach->contentDisposition(false)) {
+    if (auto cd = partToAttach->contentDisposition()) {
         part->setFileName(cd->filename());
         part->setInline(cd->disposition() == KMime::Headers::CDinline);
     }
@@ -2251,7 +2255,7 @@ void ComposerViewBase::setRequestDeleveryConfirmation(bool requestDeleveryConfir
     m_requestDeleveryConfirmation = requestDeleveryConfirmation;
 }
 
-KMime::Message::Ptr ComposerViewBase::msg() const
+std::shared_ptr<KMime::Message> ComposerViewBase::msg() const
 {
     return m_msg;
 }
