@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -49,11 +49,11 @@ static bool operator==(const KMime::Types::Mailbox &left, const KMime::Types::Ma
  * Strips all the user's addresses from an address list. This is used
  * when replying.
  */
-static KMime::Types::Mailbox::List stripMyAddressesFromAddressList(const KMime::Types::Mailbox::List &list,
-                                                                   const KIdentityManagementCore::IdentityManager *manager)
+static QList<KMime::Types::Mailbox> stripMyAddressesFromAddressList(const QList<KMime::Types::Mailbox> &list,
+                                                                    const KIdentityManagementCore::IdentityManager *manager)
 {
-    KMime::Types::Mailbox::List addresses(list);
-    for (KMime::Types::Mailbox::List::Iterator it = addresses.begin(); it != addresses.end();) {
+    QList<KMime::Types::Mailbox> addresses(list);
+    for (QList<KMime::Types::Mailbox>::Iterator it = addresses.begin(); it != addresses.end();) {
         if (manager->thatIsMe(it->prettyAddress())) {
             it = addresses.erase(it);
         } else {
@@ -64,7 +64,7 @@ static KMime::Types::Mailbox::List stripMyAddressesFromAddressList(const KMime::
     return addresses;
 }
 
-MessageFactoryNG::MessageFactoryNG(const KMime::Message::Ptr &origMsg, Akonadi::Item::Id id, const Akonadi::Collection &col, QObject *parent)
+MessageFactoryNG::MessageFactoryNG(const std::shared_ptr<KMime::Message> &origMsg, Akonadi::Item::Id id, const Akonadi::Collection &col, QObject *parent)
     : QObject(parent)
     , mOrigMsg(origMsg)
     , mFolderId(0)
@@ -79,12 +79,12 @@ MessageFactoryNG::~MessageFactoryNG() = default;
 
 // Return the addresses to use when replying to the author of msg.
 // See <https://cr.yp.to/proto/replyto.html>.
-static KMime::Types::Mailbox::List authorMailboxes(const KMime::Message::Ptr &msg, const KMime::Types::Mailbox::List &mailingLists)
+static QList<KMime::Types::Mailbox> authorMailboxes(const std::shared_ptr<KMime::Message> &msg, const QList<KMime::Types::Mailbox> &mailingLists)
 {
     if (auto mrt = msg->headerByType("Mail-Reply-To")) {
-        return KMime::Types::Mailbox::listFrom7BitString(mrt->as7BitString(false));
+        return KMime::Types::Mailbox::listFrom7BitString(mrt->as7BitString());
     }
-    if (auto rt = msg->replyTo(false)) {
+    if (auto rt = msg->replyTo(KMime::CreatePolicy::DontCreate)) {
         // Did a mailing list munge Reply-To?
         auto mboxes = rt->mailboxes();
         for (const auto &list : mailingLists) {
@@ -94,14 +94,14 @@ static KMime::Types::Mailbox::List authorMailboxes(const KMime::Message::Ptr &ms
             return mboxes;
         }
     }
-    return msg->from(true)->mailboxes();
+    return msg->from(KMime::CreatePolicy::Create)->mailboxes();
 }
 
-void MessageFactoryNG::slotCreateReplyDone(const KMime::Message::Ptr &msg, bool replyAll)
+void MessageFactoryNG::slotCreateReplyDone(const std::shared_ptr<KMime::Message> &msg, bool replyAll)
 {
     MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusReplied());
     if (mParentFolderId > 0) {
-        auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Fcc"));
+        auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-Fcc");
         header->fromUnicodeString(QString::number(mParentFolderId));
         msg->setHeader(std::move(header));
     }
@@ -111,23 +111,24 @@ void MessageFactoryNG::slotCreateReplyDone(const KMime::Message::Ptr &msg, bool
     }
     msg->assemble();
 
-    MessageReply reply;
-    reply.msg = msg;
-    reply.replyAll = replyAll;
+    const MessageReply reply{
+        .msg = msg,
+        .replyAll = replyAll,
+    };
     Q_EMIT createReplyDone(reply);
 }
 
 void MessageFactoryNG::createReplyAsync()
 {
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     QByteArray refStr;
     bool replyAll = true;
-    KMime::Types::Mailbox::List toList;
-    KMime::Types::Mailbox::List replyToList;
+    QList<KMime::Types::Mailbox> toList;
+    QList<KMime::Types::Mailbox> replyToList;
 
     const uint originalIdentity = identityUoid(mOrigMsg);
     MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
-    if (auto replyTo = mOrigMsg->replyTo(false)) {
+    if (auto replyTo = mOrigMsg->replyTo(KMime::CreatePolicy::DontCreate)) {
         replyToList = replyTo->mailboxes();
     }
 
@@ -146,10 +147,10 @@ void MessageFactoryNG::createReplyAsync()
     switch (mReplyStrategy) {
     case MessageComposer::ReplySmart: {
         if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
-            toList << KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString(false));
+            toList << KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString());
         } else if (!mMailingListAddresses.isEmpty()) {
             if (replyToList.isEmpty()) {
-                toList = (KMime::Types::Mailbox::List() << mMailingListAddresses.at(0));
+                toList = (QList<KMime::Types::Mailbox>() << mMailingListAddresses.at(0));
             } else {
                 toList = replyToList;
             }
@@ -172,7 +173,7 @@ void MessageFactoryNG::createReplyAsync()
             replyAll = false;
         }
         // strip all my addresses from the list of recipients
-        const KMime::Types::Mailbox::List recipients = toList;
+        const QList<KMime::Types::Mailbox> recipients = toList;
 
         toList = stripMyAddressesFromAddressList(recipients, mIdentityManager);
 
@@ -185,7 +186,7 @@ void MessageFactoryNG::createReplyAsync()
     case MessageComposer::ReplyList: {
         if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             KMime::Types::Mailbox mailbox;
-            mailbox.from7BitString(hdr->as7BitString(false));
+            mailbox.from7BitString(hdr->as7BitString());
             toList << mailbox;
         } else if (!mMailingListAddresses.isEmpty()) {
             toList << mMailingListAddresses[0];
@@ -195,14 +196,14 @@ void MessageFactoryNG::createReplyAsync()
         }
 
         // strip all my addresses from the list of recipients
-        const KMime::Types::Mailbox::List recipients = toList;
+        const QList<KMime::Types::Mailbox> recipients = toList;
 
         toList = stripMyAddressesFromAddressList(recipients, mIdentityManager);
         break;
     }
     case MessageComposer::ReplyAll:
         if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
-            toList = KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString(false));
+            toList = KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString());
         } else {
             auto ccList = stripMyAddressesFromAddressList(mOrigMsg->cc()->mailboxes(), mIdentityManager);
 
@@ -265,9 +266,9 @@ void MessageFactoryNG::createReplyAsync()
         msg->references()->fromUnicodeString(QString::fromLocal8Bit(refStr));
     }
     // In-Reply-To = original msg-id
-    msg->inReplyTo()->from7BitString(mOrigMsg->messageID()->as7BitString(false));
+    msg->inReplyTo()->from7BitString(mOrigMsg->messageID()->as7BitString());
 
-    msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(mOrigMsg.data()));
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(mOrigMsg.get()));
 
     // If the reply shouldn't be blank, apply the template to the message
     if (mQuote) {
@@ -287,7 +288,7 @@ void MessageFactoryNG::createReplyAsync()
     }
 }
 
-void MessageFactoryNG::slotCreateForwardDone(const KMime::Message::Ptr &msg)
+void MessageFactoryNG::slotCreateForwardDone(const std::shared_ptr<KMime::Message> &msg)
 {
     MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     msg->assemble();
@@ -296,29 +297,29 @@ void MessageFactoryNG::slotCreateForwardDone(const KMime::Message::Ptr &msg)
 
 void MessageFactoryNG::createForwardAsync()
 {
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
 
     // This is a non-multipart, non-text mail (e.g. text/calendar). Construct
     // a multipart/mixed mail and add the original body as an attachment.
     if (!mOrigMsg->contentType()->isMultipart()
-        && (!mOrigMsg->contentType(false)->isText()
-            || (mOrigMsg->contentType(false)->isText() && mOrigMsg->contentType(false)->subType() != "html"
-                && mOrigMsg->contentType(false)->subType() != "plain"))) {
+        && (!mOrigMsg->contentType(KMime::CreatePolicy::DontCreate)->isText()
+            || (mOrigMsg->contentType(KMime::CreatePolicy::DontCreate)->isText() && mOrigMsg->contentType(KMime::CreatePolicy::DontCreate)->subType() != "html"
+                && mOrigMsg->contentType(KMime::CreatePolicy::DontCreate)->subType() != "plain"))) {
         const uint originalIdentity = identityUoid(mOrigMsg);
         MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
         msg->removeHeader<KMime::Headers::ContentType>();
         msg->removeHeader<KMime::Headers::ContentTransferEncoding>();
 
-        msg->contentType(true)->setMimeType("multipart/mixed");
+        msg->contentType(KMime::CreatePolicy::Create)->setMimeType("multipart/mixed");
 
         // TODO: Andras: somebody should check if this is correct. :)
         // empty text part
-        auto msgPart = std::unique_ptr<KMime::Content>(new KMime::Content);
+        auto msgPart = std::make_unique<KMime::Content>();
         msgPart->contentType()->setMimeType("text/plain");
         msg->appendContent(std::move(msgPart));
 
         // the old contents of the mail
-        auto secondPart = std::unique_ptr<KMime::Content>(new KMime::Content);
+        auto secondPart = std::make_unique<KMime::Content>();
         secondPart->contentType()->setMimeType(mOrigMsg->contentType()->mimeType());
         secondPart->setBody(mOrigMsg->body());
         // use the headers of the original mail
@@ -333,7 +334,7 @@ void MessageFactoryNG::createForwardAsync()
         // TODO Check if this is ok
         msg->setHead(mOrigMsg->head());
         msg->setBody(mOrigMsg->body());
-        const QString oldContentType = msg->contentType(true)->asUnicodeString();
+        const QString oldContentType = msg->contentType(KMime::CreatePolicy::Create)->asUnicodeString();
         const uint originalIdentity = identityUoid(mOrigMsg);
         MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
 
@@ -343,7 +344,7 @@ void MessageFactoryNG::createForwardAsync()
         msg->assemble();
     }
 
-    msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(mOrigMsg.data()));
+    msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(mOrigMsg.get()));
     auto job = new MessageFactoryForwardJob;
     connect(job, &MessageFactoryForwardJob::forwardDone, this, &MessageFactoryNG::slotCreateForwardDone);
     job->setIdentityManager(mIdentityManager);
@@ -355,12 +356,12 @@ void MessageFactoryNG::createForwardAsync()
     job->start();
 }
 
-QPair<KMime::Message::Ptr, QList<KMime::Content *>> MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
+QPair<std::shared_ptr<KMime::Message>, std::vector<std::unique_ptr<KMime::Content>>> MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
 {
     // create forwarded message with original message as attachment
     // remove headers that shouldn't be forwarded
-    KMime::Message::Ptr msg(new KMime::Message);
-    QList<KMime::Content *> attachments;
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
+    std::vector<std::unique_ptr<KMime::Content>> attachments;
 
     const int numberOfItems(items.count());
     if (numberOfItems >= 2) {
@@ -368,38 +369,38 @@ QPair<KMime::Message::Ptr, QList<KMime::Content *>> MessageFactoryNG::createAtta
         // the selected mails
         MessageHelper::initHeader(msg, mIdentityManager, 0);
     } else if (numberOfItems == 1) {
-        KMime::Message::Ptr firstMsg = MessageComposer::Util::message(items.first());
+        std::shared_ptr<KMime::Message> firstMsg = MessageComposer::Util::message(items.first());
         const uint originalIdentity = identityUoid(firstMsg);
         MessageHelper::initFromMessage(msg, firstMsg, mIdentityManager, originalIdentity);
-        msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(firstMsg.data()));
+        msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(firstMsg.get()));
     }
 
     MessageHelper::setAutomaticFields(msg, true);
     KCursorSaver saver(Qt::WaitCursor);
     if (numberOfItems == 0) {
-        attachments << createForwardAttachmentMessage(mOrigMsg);
+        attachments.push_back(createForwardAttachmentMessage(mOrigMsg));
         MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     } else {
         // iterate through all the messages to be forwarded
         attachments.reserve(items.count());
         for (const Akonadi::Item &item : std::as_const(items)) {
-            attachments << createForwardAttachmentMessage(MessageComposer::Util::message(item));
+            attachments.push_back(createForwardAttachmentMessage(MessageComposer::Util::message(item)));
             MessageComposer::Util::addLinkInformation(msg, item.id(), Akonadi::MessageStatus::statusForwarded());
         }
     }
 
     // msg->assemble();
-    return QPair<KMime::Message::Ptr, QList<KMime::Content *>>(msg, QList<KMime::Content *>() << attachments);
+    return std::make_pair(std::move(msg), std::move(attachments));
 }
 
-KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Message::Ptr &fwdMsg)
+std::unique_ptr<KMime::Content> MessageFactoryNG::createForwardAttachmentMessage(const std::shared_ptr<KMime::Message> &fwdMsg)
 {
     // remove headers that shouldn't be forwarded
     MessageCore::StringUtil::removePrivateHeaderFields(fwdMsg);
     fwdMsg->removeHeader<KMime::Headers::Bcc>();
     fwdMsg->assemble();
     // set the part
-    auto msgPart = new KMime::Content(fwdMsg.data());
+    auto msgPart = std::make_unique<KMime::Content>();
     auto ct = msgPart->contentType();
     ct->setMimeType("message/rfc822");
 
@@ -426,25 +427,27 @@ void MessageFactoryNG::setReplyAsHtml(bool replyAsHtml)
     mReplyAsHtml = replyAsHtml;
 }
 
-KMime::Message::Ptr MessageFactoryNG::createResend()
+std::shared_ptr<KMime::Message> MessageFactoryNG::createResend()
 {
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     msg->setContent(mOrigMsg->encodedContent());
     msg->parse();
     msg->removeHeader<KMime::Headers::MessageID>();
     uint originalIdentity = identityUoid(mOrigMsg);
 
     // Set the identity from above
-    auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Identity"));
+    auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-Identity");
     header->fromUnicodeString(QString::number(originalIdentity));
     msg->setHeader(std::move(header));
 
     // Restore the original bcc field as this is overwritten in applyIdentity
-    msg->bcc(mOrigMsg->bcc());
+    if (auto origBcc = mOrigMsg->bcc(KMime::DontCreate)) {
+        msg->bcc(KMime::Create)->from7BitString(origBcc->as7BitString());
+    }
     return msg;
 }
 
-KMime::Message::Ptr
+std::shared_ptr<KMime::Message>
 MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, const QString &bccStr, int transportId, const QString &fcc, int identity)
 {
     if (!mOrigMsg) {
@@ -452,7 +455,7 @@ MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, con
     }
 
     // copy the message 1:1
-    KMime::Message::Ptr msg(new KMime::Message);
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
     msg->setContent(mOrigMsg->encodedContent());
     msg->parse();
 
@@ -488,63 +491,63 @@ MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, con
     // date, from to and id will be set anyway
 
     // prepend Resent-*: headers (c.f. RFC2822 3.6.6)
-    QString msgIdSuffix;
-    if (MessageComposer::MessageComposerSettings::useCustomMessageIdSuffix()) {
-        msgIdSuffix = MessageComposer::MessageComposerSettings::customMsgIDSuffix();
+    auto header = std::make_unique<KMime::Headers::Generic>("Resent-Message-ID");
+    {
+        auto messageId = std::make_unique<KMime::Headers::MessageID>();
+        messageId->generate(msg->sender()->mailbox().addrSpec().domain.toUtf8());
+        header->fromUnicodeString(messageId->asUnicodeString());
     }
-    auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-Message-ID"));
-    header->fromUnicodeString(MessageCore::StringUtil::generateMessageId(msg->sender()->asUnicodeString(), msgIdSuffix));
     msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-Date"));
+    header = std::make_unique<KMime::Headers::Generic>("Resent-Date");
     header->fromUnicodeString(newDate);
     msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-From"));
+    header = std::make_unique<KMime::Headers::Generic>("Resent-From");
     header->fromUnicodeString(strFrom);
     msg->setHeader(std::move(header));
 
-    if (msg->to(false)) {
-        auto headerT = std::unique_ptr<KMime::Headers::To>(new KMime::Headers::To);
+    if (msg->to(KMime::CreatePolicy::DontCreate)) {
+        auto headerT = std::make_unique<KMime::Headers::To>();
         headerT->fromUnicodeString(mOrigMsg->to()->asUnicodeString());
-        msg->setHeader(std::move(header));
+        msg->setHeader(std::move(headerT));
     }
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-To"));
+    header = std::make_unique<KMime::Headers::Generic>("Resent-To");
     header->fromUnicodeString(toStr);
     msg->setHeader(std::move(std::move(header)));
 
     if (!ccStr.isEmpty()) {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-Cc"));
+        header = std::make_unique<KMime::Headers::Generic>("Resent-Cc");
         header->fromUnicodeString(ccStr);
         msg->setHeader(std::move(header));
     }
 
     if (!bccStr.isEmpty()) {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("Resent-Bcc"));
+        header = std::make_unique<KMime::Headers::Generic>("Resent-Bcc");
         header->fromUnicodeString(bccStr);
         msg->setHeader(std::move(header));
     }
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Redirect-From"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Redirect-From");
     header->fromUnicodeString(strByWayOf);
     msg->setHeader(std::move(header));
 
     if (transportId != -1) {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Transport"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-Transport");
         header->fromUnicodeString(QString::number(transportId));
         msg->setHeader(std::move(header));
     }
 
     if (!fcc.isEmpty()) {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Fcc"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-Fcc");
         header->fromUnicodeString(fcc);
         msg->setHeader(std::move(header));
     }
 
     const bool fccIsDisabled = ident.disabledFcc();
     if (fccIsDisabled) {
-        header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-FccDisabled"));
+        header = std::make_unique<KMime::Headers::Generic>("X-KMail-FccDisabled");
         header->fromUnicodeString(u"true"_s);
         msg->setHeader(std::move(header));
     } else {
@@ -557,7 +560,7 @@ MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, con
     return msg;
 }
 
-KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
+std::shared_ptr<KMime::Message> MessageFactoryNG::createDeliveryReceipt()
 {
     QString receiptTo;
     if (auto hrd = mOrigMsg->headerByType("Disposition-Notification-To")) {
@@ -568,7 +571,7 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
     }
     receiptTo.remove(u'\n');
 
-    KMime::Message::Ptr receipt(new KMime::Message);
+    std::shared_ptr<KMime::Message> receipt(new KMime::Message);
     const uint originalIdentity = identityUoid(mOrigMsg);
     MessageHelper::initFromMessage(receipt, mOrigMsg, mIdentityManager, originalIdentity);
     receipt->to()->fromUnicodeString(receiptTo);
@@ -587,11 +590,11 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
     return receipt;
 }
 
-KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
-                                                KMime::MDN::DispositionType d,
-                                                KMime::MDN::SendingMode s,
-                                                int mdnQuoteOriginal,
-                                                const QList<KMime::MDN::DispositionModifier> &m)
+std::shared_ptr<KMime::Message> MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
+                                                            KMime::MDN::DispositionType d,
+                                                            KMime::MDN::SendingMode s,
+                                                            int mdnQuoteOriginal,
+                                                            const QList<KMime::MDN::DispositionModifier> &m)
 {
     // extract where to send to:
     QString receiptTo;
@@ -599,7 +602,7 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
         receiptTo = hrd->asUnicodeString();
     }
     if (receiptTo.trimmed().isEmpty()) {
-        return KMime::Message::Ptr(new KMime::Message);
+        return std::shared_ptr<KMime::Message>(new KMime::Message);
     }
     receiptTo.remove(u'\n');
 
@@ -612,10 +615,10 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
     // Generate message:
     //
 
-    KMime::Message::Ptr receipt(new KMime::Message());
+    std::shared_ptr<KMime::Message> receipt(new KMime::Message());
     const uint originalIdentity = identityUoid(mOrigMsg);
     MessageHelper::initFromMessage(receipt, mOrigMsg, mIdentityManager, originalIdentity);
-    auto contentType = receipt->contentType(true); // create it
+    auto contentType = receipt->contentType(KMime::CreatePolicy::Create); // create it
     contentType->from7BitString("multipart/report");
     contentType->setBoundary(KMime::multiPartBoundary());
     contentType->setCharset("us-ascii");
@@ -626,62 +629,61 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
     const QString description = replaceHeadersInString(mOrigMsg, KMime::MDN::descriptionFor(d, m));
 
     // text/plain part:
-    auto firstMsgPart = new KMime::Content(mOrigMsg.data());
+    auto firstMsgPart = std::make_unique<KMime::Content>();
     auto firstMsgPartContentType = firstMsgPart->contentType(); // create it
     firstMsgPartContentType->setMimeType("text/plain");
     firstMsgPartContentType->setCharset("utf-8");
-    firstMsgPart->contentTransferEncoding(true)->setEncoding(KMime::Headers::CE7Bit);
+    firstMsgPart->contentTransferEncoding(KMime::CreatePolicy::Create)->setEncoding(KMime::Headers::CE7Bit);
     firstMsgPart->setBody(description.toUtf8());
-    receipt->appendContent(firstMsgPart);
+    receipt->appendContent(std::move(firstMsgPart));
 
     // message/disposition-notification part:
-    auto secondMsgPart = new KMime::Content(mOrigMsg.data());
+    auto secondMsgPart = std::make_unique<KMime::Content>();
     secondMsgPart->contentType()->setMimeType("message/disposition-notification");
 
     secondMsgPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
     QByteArray originalRecipient = "";
     if (auto hrd = mOrigMsg->headerByType("Original-Recipient")) {
-        originalRecipient = hrd->as7BitString(false);
+        originalRecipient = hrd->as7BitString();
     }
     secondMsgPart->setBody(KMime::MDN::dispositionNotificationBodyContent(finalRecipient,
                                                                           originalRecipient,
-                                                                          mOrigMsg->messageID()->as7BitString(false), /* Message-ID */
+                                                                          mOrigMsg->messageID()->as7BitString(), /* Message-ID */
                                                                           d,
                                                                           a,
                                                                           s,
                                                                           m,
                                                                           special));
-    receipt->appendContent(secondMsgPart);
+    receipt->appendContent(std::move(secondMsgPart));
 
     if ((mdnQuoteOriginal < 0) || (mdnQuoteOriginal > 2)) {
         mdnQuoteOriginal = 0;
     }
     /* 0=> Nothing, 1=>Full Message, 2=>HeadersOnly*/
 
-    auto thirdMsgPart = new KMime::Content(mOrigMsg.data());
+    auto thirdMsgPart = std::make_unique<KMime::Content>();
     switch (mdnQuoteOriginal) {
     case 1:
         thirdMsgPart->contentType()->setMimeType("message/rfc822");
         thirdMsgPart->setBody(MessageCore::StringUtil::asSendableString(mOrigMsg));
-        receipt->appendContent(thirdMsgPart);
+        receipt->appendContent(std::move(thirdMsgPart));
         break;
     case 2:
         thirdMsgPart->contentType()->setMimeType("text/rfc822-headers");
         thirdMsgPart->setBody(MessageCore::StringUtil::headerAsSendableString(mOrigMsg));
-        receipt->appendContent(thirdMsgPart);
+        receipt->appendContent(std::move(thirdMsgPart));
         break;
     case 0:
     default:
-        delete thirdMsgPart;
         break;
     }
 
     receipt->to()->fromUnicodeString(receiptTo);
     // Laurent: We don't translate subject ?
     receipt->subject()->from7BitString("Message Disposition Notification");
-    auto header = new KMime::Headers::InReplyTo;
+    auto header = std::make_unique<KMime::Headers::InReplyTo>();
     header->fromUnicodeString(mOrigMsg->messageID()->asUnicodeString());
-    receipt->setHeader(header);
+    receipt->setHeader(std::move(header));
 
     receipt->references()->from7BitString(getRefStr(mOrigMsg));
 
@@ -693,10 +695,10 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
     return receipt;
 }
 
-QPair<KMime::Message::Ptr, KMime::Content *> MessageFactoryNG::createForwardDigestMIME(const Akonadi::Item::List &items)
+QPair<std::shared_ptr<KMime::Message>, std::unique_ptr<KMime::Content>> MessageFactoryNG::createForwardDigestMIME(const Akonadi::Item::List &items)
 {
-    KMime::Message::Ptr msg(new KMime::Message);
-    auto digest = new KMime::Content(msg.data());
+    std::shared_ptr<KMime::Message> msg(new KMime::Message);
+    auto digest = std::make_unique<KMime::Content>();
 
     const QString mainPartText = i18n(
         "\nThis is a MIME digest forward. The content of the"
@@ -711,7 +713,7 @@ QPair<KMime::Message::Ptr, KMime::Content *> MessageFactoryNG::createForwardDige
 
     int id = 0;
     for (const Akonadi::Item &item : std::as_const(items)) {
-        KMime::Message::Ptr fMsg = MessageComposer::Util::message(item);
+        std::shared_ptr<KMime::Message> fMsg = MessageComposer::Util::message(item);
         if (id == 0) {
             if (auto hrd = fMsg->headerByType("X-KMail-Identity")) {
                 id = hrd->asUnicodeString().toInt();
@@ -721,17 +723,17 @@ QPair<KMime::Message::Ptr, KMime::Content *> MessageFactoryNG::createForwardDige
         MessageCore::StringUtil::removePrivateHeaderFields(fMsg);
         fMsg->removeHeader<KMime::Headers::Bcc>();
         fMsg->assemble();
-        auto part = new KMime::Content(digest);
+        auto part = std::make_unique<KMime::Content>();
 
         part->contentType()->setMimeType("message/rfc822");
-        part->contentType(false)->setCharset(fMsg->contentType()->charset());
+        part->contentType(KMime::CreatePolicy::DontCreate)->setCharset(fMsg->contentType()->charset());
         part->contentID()->setIdentifier(fMsg->contentID()->identifier());
         part->contentDescription()->fromUnicodeString(fMsg->contentDescription()->asUnicodeString());
         part->contentDisposition()->setParameter(QByteArrayLiteral("name"), i18n("forwarded message"));
         part->fromUnicodeString(QString::fromLatin1(fMsg->encodedContent()));
         part->assemble();
         MessageComposer::Util::addLinkInformation(msg, item.id(), Akonadi::MessageStatus::statusForwarded());
-        digest->appendContent(part);
+        digest->appendContent(std::move(part));
     }
     digest->assemble();
 
@@ -740,7 +742,7 @@ QPair<KMime::Message::Ptr, KMime::Content *> MessageFactoryNG::createForwardDige
 
     //   qCDebug(MESSAGECOMPOSER_LOG) << "digest:" << digest->contents().size() << digest->encodedContent();
 
-    return QPair<KMime::Message::Ptr, KMime::Content *>(msg, digest);
+    return std::make_pair(std::move(msg), std::move(digest));
 }
 
 void MessageFactoryNG::setIdentityManager(KIdentityManagementCore::IdentityManager *ident)
@@ -768,7 +770,7 @@ void MessageFactoryNG::setTemplate(const QString &templ)
     mTemplate = templ;
 }
 
-void MessageFactoryNG::setMailingListAddresses(const KMime::Types::Mailbox::List &listAddresses)
+void MessageFactoryNG::setMailingListAddresses(const QList<KMime::Types::Mailbox> &listAddresses)
 {
     mMailingListAddresses << listAddresses;
 }
@@ -783,7 +785,7 @@ void MessageFactoryNG::putRepliesInSameFolder(Akonadi::Collection::Id parentColI
     mParentFolderId = parentColId;
 }
 
-bool MessageFactoryNG::MDNRequested(const KMime::Message::Ptr &msg)
+bool MessageFactoryNG::MDNRequested(const std::shared_ptr<KMime::Message> &msg)
 {
     // extract where to send to:
     QString receiptTo;
@@ -797,7 +799,7 @@ bool MessageFactoryNG::MDNRequested(const KMime::Message::Ptr &msg)
     return !receiptTo.isEmpty();
 }
 
-bool MessageFactoryNG::MDNConfirmMultipleRecipients(const KMime::Message::Ptr &msg)
+bool MessageFactoryNG::MDNConfirmMultipleRecipients(const std::shared_ptr<KMime::Message> &msg)
 {
     // extract where to send to:
     QString receiptTo;
@@ -817,7 +819,7 @@ bool MessageFactoryNG::MDNConfirmMultipleRecipients(const KMime::Message::Ptr &m
     return KEmailAddress::splitAddressList(receiptTo).count() > 1;
 }
 
-bool MessageFactoryNG::MDNReturnPathEmpty(const KMime::Message::Ptr &msg)
+bool MessageFactoryNG::MDNReturnPathEmpty(const std::shared_ptr<KMime::Message> &msg)
 {
     // extract where to send to:
     QString receiptTo;
@@ -834,13 +836,13 @@ bool MessageFactoryNG::MDNReturnPathEmpty(const KMime::Message::Ptr &msg)
     // in the Return-Path header. [...] Confirmation from the user
     // SHOULD be obtained (or no MDN sent) if there is no Return-Path
     // header in the message [...]
-    KMime::Types::AddrSpecList returnPathList = MessageHelper::extractAddrSpecs(msg, "Return-Path");
+    const auto returnPathList = MessageHelper::extractAddrSpecs(msg, "Return-Path");
     const QString returnPath = returnPathList.isEmpty() ? QString() : returnPathList.front().localPart + u'@' + returnPathList.front().domain;
     qCDebug(MESSAGECOMPOSER_LOG) << "clean return path:" << returnPath;
     return returnPath.isEmpty();
 }
 
-bool MessageFactoryNG::MDNReturnPathNotInRecieptTo(const KMime::Message::Ptr &msg)
+bool MessageFactoryNG::MDNReturnPathNotInRecieptTo(const std::shared_ptr<KMime::Message> &msg)
 {
     // extract where to send to:
     QString receiptTo;
@@ -857,13 +859,13 @@ bool MessageFactoryNG::MDNReturnPathNotInRecieptTo(const KMime::Message::Ptr &ms
     // in the Return-Path header. [...] Confirmation from the user
     // SHOULD be obtained (or no MDN sent) if there is no Return-Path
     // header in the message [...]
-    KMime::Types::AddrSpecList returnPathList = MessageHelper::extractAddrSpecs(msg, u"Return-Path"_s.toLatin1());
+    const auto returnPathList = MessageHelper::extractAddrSpecs(msg, u"Return-Path"_s.toLatin1());
     const QString returnPath = returnPathList.isEmpty() ? QString() : returnPathList.front().localPart + u'@' + returnPathList.front().domain;
     qCDebug(MESSAGECOMPOSER_LOG) << "clean return path:" << returnPath;
     return !receiptTo.contains(returnPath, Qt::CaseSensitive);
 }
 
-bool MessageFactoryNG::MDNMDNUnknownOption(const KMime::Message::Ptr &msg)
+bool MessageFactoryNG::MDNMDNUnknownOption(const std::shared_ptr<KMime::Message> &msg)
 {
     // RFC 2298: An importance of "required" indicates that
     // interpretation of the parameter is necessary for proper
@@ -884,7 +886,7 @@ bool MessageFactoryNG::MDNMDNUnknownOption(const KMime::Message::Ptr &msg)
     return false;
 }
 
-uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
+uint MessageFactoryNG::identityUoid(const std::shared_ptr<KMime::Message> &msg)
 {
     QString idString;
     if (auto hdr = msg->headerByType("X-KMail-Identity")) {
@@ -894,12 +896,12 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
     uint id = idString.toUInt(&ok);
 
     if (!ok || id == 0) {
-        id = MessageCore::Util::identityForMessage(msg.data(), mIdentityManager, mFolderId).uoid();
+        id = MessageCore::Util::identityForMessage(msg.get(), mIdentityManager, mFolderId).uoid();
     }
     return id;
 }
 
-QString MessageFactoryNG::replaceHeadersInString(const KMime::Message::Ptr &msg, const QString &s)
+QString MessageFactoryNG::replaceHeadersInString(const std::shared_ptr<KMime::Message> &msg, const QString &s)
 {
     QString result = s;
     static QRegularExpression rx{u"\\$\\{([a-z0-9-]+)\\}"_s, QRegularExpression::CaseInsensitiveOption};
@@ -924,7 +926,7 @@ QString MessageFactoryNG::replaceHeadersInString(const KMime::Message::Ptr &msg,
     return result;
 }
 
-QByteArray MessageFactoryNG::getRefStr(const KMime::Message::Ptr &msg)
+QByteArray MessageFactoryNG::getRefStr(const std::shared_ptr<KMime::Message> &msg)
 {
     QByteArray firstRef;
     QByteArray lastRef;
@@ -933,12 +935,12 @@ QByteArray MessageFactoryNG::getRefStr(const KMime::Message::Ptr &msg)
     int i;
     int j;
 
-    if (auto hdr = msg->references(false)) {
-        refStr = hdr->as7BitString(false).trimmed();
+    if (auto hdr = msg->references(KMime::CreatePolicy::DontCreate)) {
+        refStr = hdr->as7BitString().trimmed();
     }
 
     if (refStr.isEmpty()) {
-        return msg->messageID()->as7BitString(false);
+        return msg->messageID()->as7BitString();
     }
 
     i = refStr.indexOf('<');
@@ -956,7 +958,7 @@ QByteArray MessageFactoryNG::getRefStr(const KMime::Message::Ptr &msg)
         retRefStr += lastRef + ' ';
     }
 
-    retRefStr += msg->messageID()->as7BitString(false);
+    retRefStr += msg->messageID()->as7BitString();
     return retRefStr;
 }
 
