@@ -40,25 +40,19 @@ public:
     {
     }
 
-    ~ComposerJobPrivate() override
-    {
-        delete skeletonMessage;
-    }
-
     void init();
     void doStart(); // slot
     void composeStep1();
     void composeStep2();
     [[nodiscard]] QList<ContentJobBase *> createEncryptJobs(ContentJobBase *contentJob, bool sign);
     void contentJobFinished(KJob *job); // slot
-    void composeWithLateAttachments(KMime::Message *headers,
-                                    KMime::Content *content,
+    void composeWithLateAttachments(std::unique_ptr<KMime::Content> &&content,
                                     const AttachmentPart::List &parts,
                                     const std::vector<GpgME::Key> &keys,
                                     const QStringList &recipients);
-    void attachmentsFinished(KJob *job); // slot
+    void attachmentsFinished(KJob *job);
 
-    void composeFinalStep(KMime::Content *headers, KMime::Content *content);
+    void composeFinalStep(std::unique_ptr<KMime::Content> &&content);
 
     QString gnupgHome;
     QList<QPair<QStringList, std::vector<GpgME::Key>>> encData;
@@ -68,7 +62,7 @@ public:
     // attachments with different sign/encrypt settings from
     // main message body. added at the end of the process
     AttachmentPart::List lateAttachmentParts;
-    QList<KMime::Message::Ptr> resultMessages;
+    QList<std::shared_ptr<KMime::Message>> resultMessages;
 
     Kleo::CryptoMessageFormat format;
 
@@ -79,7 +73,7 @@ public:
     ItipPart *itipPart = nullptr;
 
     // Stuff that we play with.
-    KMime::Message *skeletonMessage = nullptr;
+    std::unique_ptr<KMime::Message> skeletonMessage;
 
     bool started = false;
     bool finished = false;
@@ -123,7 +117,7 @@ void ComposerJobPrivate::composeStep1()
 
         // SkeletonMessageJob is a special job creating a Message instead of a Content.
         Q_ASSERT(skeletonMessage == nullptr);
-        skeletonMessage = skeletonJob->message();
+        skeletonMessage = std::move(skeletonJob->takeMessage());
         Q_ASSERT(skeletonMessage);
         skeletonMessage->assemble();
 
@@ -170,7 +164,9 @@ void ComposerJobPrivate::composeStep2()
                     mainJob = multipartJob;
                 }
 
-                QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
+                QObject::connect(mainJob, &KJob::finished, q, [this](KJob *job) {
+                    contentJobFinished(job);
+                });
                 q->addSubjob(mainJob);
             }
         } else {
@@ -191,7 +187,9 @@ void ComposerJobPrivate::composeStep2()
                 }
                 mainJob = multipartJob;
             }
-            QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
+            QObject::connect(mainJob, &KJob::finished, q, [this](KJob *job) {
+                contentJobFinished(job);
+            });
             q->addSubjob(mainJob);
         }
 
@@ -229,7 +227,7 @@ void ComposerJobPrivate::composeStep2()
 
     if (autocryptEnabled) {
         auto autocryptJob = new AutocryptHeadersJob();
-        autocryptJob->setSkeletonMessage(skeletonMessage);
+        autocryptJob->setSkeletonMessage(skeletonMessage.get());
         autocryptJob->setGnupgHome(gnupgHome);
         autocryptJob->appendSubjob(mainJob);
         autocryptJob->setSenderKey(senderEncryptionKey);
@@ -247,7 +245,7 @@ void ComposerJobPrivate::composeStep2()
         sJob->setCryptoMessageFormat(format);
         sJob->setSigningKeys(signers);
         sJob->appendSubjob(mainJob);
-        sJob->setSkeletonMessage(skeletonMessage);
+        sJob->setSkeletonMessage(skeletonMessage.get());
         mainJob = sJob;
     }
 
@@ -259,12 +257,16 @@ void ComposerJobPrivate::composeStep2()
                 // When doing Encrypt and Sign move headers only in the signed part
                 eJob->setProtectedHeaders(false);
             }
-            QObject::connect(job, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
+            QObject::connect(job, &KJob::finished, q, [this](KJob *job) {
+                contentJobFinished(job);
+            });
             q->addSubjob(job);
             mainJob = job; // start only last EncryptJob
         }
     } else {
-        QObject::connect(mainJob, SIGNAL(finished(KJob *)), q, SLOT(contentJobFinished(KJob *)));
+        QObject::connect(mainJob, &KJob::finished, q, [this](KJob *job) {
+            contentJobFinished(job);
+        });
         q->addSubjob(mainJob);
     }
 
@@ -304,7 +306,7 @@ QList<ContentJobBase *> ComposerJobPrivate::createEncryptJobs(ContentJobBase *co
             seJob->setSigningKeys(signers);
             seJob->setEncryptionKeys(recipients.second);
             seJob->setRecipients(recipients.first);
-            seJob->setSkeletonMessage(skeletonMessage);
+            seJob->setSkeletonMessage(skeletonMessage.get());
 
             subJob = seJob;
         } else {
@@ -312,7 +314,7 @@ QList<ContentJobBase *> ComposerJobPrivate::createEncryptJobs(ContentJobBase *co
             eJob->setCryptoMessageFormat(format);
             eJob->setEncryptionKeys(recipients.second);
             eJob->setRecipients(recipients.first);
-            eJob->setSkeletonMessage(skeletonMessage);
+            eJob->setSkeletonMessage(skeletonMessage.get());
             eJob->setGnupgHome(gnupgHome);
             subJob = eJob;
         }
@@ -331,8 +333,7 @@ void ComposerJobPrivate::contentJobFinished(KJob *job)
     }
     qCDebug(MESSAGECOMPOSER_LOG) << "composing final message";
 
-    KMime::Message *headers = nullptr;
-    KMime::Content *resultContent = nullptr;
+    std::unique_ptr<KMime::Content> resultContent;
     std::vector<GpgME::Key> keys;
     QStringList recipients;
 
@@ -348,22 +349,23 @@ void ComposerJobPrivate::contentJobFinished(KJob *job)
         keys = eJob->encryptionKeys();
         recipients = eJob->recipients();
 
-        resultContent = contentJob->content(); // content() comes from superclass
-        headers = new KMime::Message;
-        headers->setHeader(skeletonMessage->from());
-        headers->setHeader(skeletonMessage->to());
-        headers->setHeader(skeletonMessage->cc());
-        headers->setHeader(skeletonMessage->subject());
-        headers->setHeader(skeletonMessage->date());
-        headers->setHeader(skeletonMessage->messageID());
+        resultContent = std::move(contentJob->takeContent()); // content() comes from superclass
+        auto headers = std::make_unique<KMime::Message>();
+        headers->from(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->from()->as7BitString());
+        headers->to(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->to()->as7BitString());
+        headers->cc(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->cc()->as7BitString());
+        headers->subject(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->subject()->as7BitString());
+        headers->date(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->date()->as7BitString());
+        headers->messageID(KMime::CreatePolicy::Create)->from7BitString(skeletonMessage->messageID()->as7BitString());
 
-        auto realTo = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-EncBccRecipients"));
+        auto realTo = std::make_unique<KMime::Headers::Generic>("X-KMail-EncBccRecipients");
         realTo->fromUnicodeString(eJob->recipients().join(u'%'));
 
         qCDebug(MESSAGECOMPOSER_LOG) << "got one of multiple messages sending to:" << realTo->asUnicodeString();
         qCDebug(MESSAGECOMPOSER_LOG) << "sending to recipients:" << recipients;
         headers->setHeader(std::move(realTo));
         headers->assemble();
+        skeletonMessage = std::move(headers);
     } else { // just use the saved headers from before
         if (!encData.isEmpty()) {
             const auto firstElement = encData.at(0);
@@ -372,19 +374,17 @@ void ComposerJobPrivate::contentJobFinished(KJob *job)
             recipients = firstElement.first;
         }
 
-        headers = skeletonMessage;
-        resultContent = contentJob->content();
+        resultContent = std::move(contentJob->takeContent());
     }
 
     if (lateAttachmentParts.isEmpty()) {
-        composeFinalStep(headers, resultContent);
+        composeFinalStep(std::move(resultContent));
     } else {
-        composeWithLateAttachments(headers, resultContent, lateAttachmentParts, keys, recipients);
+        composeWithLateAttachments(std::move(resultContent), lateAttachmentParts, keys, recipients);
     }
 }
 
-void ComposerJobPrivate::composeWithLateAttachments(KMime::Message *headers,
-                                                    KMime::Content *content,
+void ComposerJobPrivate::composeWithLateAttachments(std::unique_ptr<KMime::Content> &&content,
                                                     const AttachmentPart::List &parts,
                                                     const std::vector<GpgME::Key> &keys,
                                                     const QStringList &recipients)
@@ -396,9 +396,8 @@ void ComposerJobPrivate::composeWithLateAttachments(KMime::Message *headers,
 
     // wrap the content into a job for the multijob to handle it
     auto tJob = new MessageComposer::TransparentJob(q);
-    tJob->setContent(content);
+    tJob->setContent(std::move(content));
     multiJob->appendSubjob(tJob);
-    multiJob->setExtraContent(headers);
 
     qCDebug(MESSAGECOMPOSER_LOG) << "attachment encr key size:" << keys.size() << " recipients: " << recipients;
 
@@ -445,7 +444,9 @@ void ComposerJobPrivate::composeWithLateAttachments(KMime::Message *headers,
         }
     }
 
-    QObject::connect(multiJob, SIGNAL(finished(KJob *)), q, SLOT(attachmentsFinished(KJob *)));
+    QObject::connect(multiJob, &KJob::finished, q, [this](KJob *job) {
+        attachmentsFinished(job);
+    });
 
     q->addSubjob(multiJob);
     multiJob->start();
@@ -461,21 +462,16 @@ void ComposerJobPrivate::attachmentsFinished(KJob *job)
     Q_ASSERT(dynamic_cast<ContentJobBase *>(job));
     auto contentJob = static_cast<ContentJobBase *>(job);
 
-    KMime::Content *content = contentJob->content();
-    KMime::Content *headers = contentJob->extraContent();
-
-    composeFinalStep(headers, content);
+    composeFinalStep(contentJob->takeContent());
 }
 
-void ComposerJobPrivate::composeFinalStep(KMime::Content *headers, KMime::Content *content)
+void ComposerJobPrivate::composeFinalStep(std::unique_ptr<KMime::Content> &&content)
 {
     content->assemble();
 
-    const QByteArray allData = headers->head() + content->encodedContent();
+    const QByteArray allData = skeletonMessage->head() + content->encodedContent();
 
-    delete content;
-
-    KMime::Message::Ptr resultMessage(new KMime::Message);
+    std::shared_ptr<KMime::Message> resultMessage(new KMime::Message);
     resultMessage->setContent(allData);
     resultMessage->parse(); // Not strictly necessary.
     resultMessages.append(resultMessage);
@@ -490,7 +486,7 @@ ComposerJob::ComposerJob(QObject *parent)
 
 ComposerJob::~ComposerJob() = default;
 
-QList<KMime::Message::Ptr> ComposerJob::resultMessages() const
+QList<std::shared_ptr<KMime::Message>> ComposerJob::resultMessages() const
 {
     Q_D(const ComposerJob);
     Q_ASSERT(d->finished);
