@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,24 +13,42 @@ namespace MessageComposer
 {
 class PluginEditorManagerPrivate;
 class PluginEditor;
-/**
- * @brief The PluginEditorManager class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ \class MessageComposer::PluginEditorManager
+ \inmodule MessageComposer
+ \inheaderfile MessageComposer/PluginEditorManager
+ \author Laurent Montel <montel@kde.org>
+
+ The PluginEditorManager class.
  */
 class MESSAGECOMPOSER_EXPORT PluginEditorManager : public QObject
 {
     Q_OBJECT
 public:
+    /*!
+     */
     ~PluginEditorManager() override;
 
+    /*!
+     */
     static PluginEditorManager *self();
 
+    /*!
+     */
     [[nodiscard]] QList<PluginEditor *> pluginsList() const;
 
+    /*!
+     */
     [[nodiscard]] QList<TextAddonsWidgets::PluginUtilData> pluginsDataList() const;
 
+    /*!
+     */
     [[nodiscard]] QString configGroupName() const;
+    /*!
+     */
     [[nodiscard]] QString configPrefixSettingKey() const;
+    /*!
+     */
     [[nodiscard]] PluginEditor *pluginFromIdentifier(const QString &id);
 
 private:
