@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,23 +13,41 @@ namespace MessageComposer
 {
 class PluginEditorCheckBeforeSendManagerPrivate;
 class PluginEditorCheckBeforeSend;
-/**
- * @brief The PluginEditorCheckBeforeSendManager class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ \class MessageComposer::PluginEditorCheckBeforeSendManager
+ \inmodule MessageComposer
+ \inheaderfile MessageComposer/PluginEditorCheckBeforeSendManager
+ \author Laurent Montel <montel@kde.org>
+
+ The PluginEditorCheckBeforeSendManager class.
  */
 class MESSAGECOMPOSER_EXPORT PluginEditorCheckBeforeSendManager : public QObject
 {
     Q_OBJECT
 public:
+    /*!
+     */
     ~PluginEditorCheckBeforeSendManager() override;
 
+    /*!
+     */
     static PluginEditorCheckBeforeSendManager *self();
 
+    /*!
+     */
     [[nodiscard]] QList<PluginEditorCheckBeforeSend *> pluginsList() const;
 
+    /*!
+     */
     [[nodiscard]] QString configGroupName() const;
+    /*!
+     */
     [[nodiscard]] QString configPrefixSettingKey() const;
+    /*!
+     */
     [[nodiscard]] QList<TextAddonsWidgets::PluginUtilData> pluginsDataList() const;
+    /*!
+     */
     [[nodiscard]] PluginEditorCheckBeforeSend *pluginFromIdentifier(const QString &id);
 
 private:
