@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,23 +14,43 @@ namespace MessageComposer
 {
 class PluginEditorInitManagerPrivate;
 class PluginEditorInit;
-/**
- * @brief The PluginEditorInitManager class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ \class MessageComposer::PluginEditorInitManager
+ \inmodule MessageComposer
+ \inheaderfile MessageComposer/PluginEditorInitManager
+ \author Laurent Montel <montel@kde.org>
+
+ The PluginEditorInitManager class.
  */
 class MESSAGECOMPOSER_EXPORT PluginEditorInitManager : public QObject
 {
     Q_OBJECT
 public:
+    /*!
+     */
     ~PluginEditorInitManager() override;
 
+    /*!
+     */
     static PluginEditorInitManager *self();
 
+    /*!
+     */
     [[nodiscard]] QList<PluginEditorInit *> pluginsList() const;
 
+    /*!
+     */
     [[nodiscard]] QString configGroupName() const;
+    /*!
+     */
+    /*!
+     */
     [[nodiscard]] QString configPrefixSettingKey() const;
+    /*!
+     */
     [[nodiscard]] QList<TextAddonsWidgets::PluginUtilData> pluginsDataList() const;
+    /*!
+     */
     [[nodiscard]] PluginEditorInit *pluginFromIdentifier(const QString &id);
 
 private:
