@@ -33,7 +33,7 @@
 #include <MessageCore/StringUtil>
 using namespace Qt::Literals::StringLiterals;
 
-static KMime::Content *setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::ContentType *contentType, KMime::Content *ret)
+static void setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::ContentType *contentType, KMime::Content *ret)
 {
     MessageComposer::ComposerJob composerJob;
     MessageComposer::SinglepartJob cteJob(&composerJob);
@@ -42,28 +42,27 @@ static KMime::Content *setBodyAndCTE(QByteArray &encodedBody, KMime::Headers::Co
     cteJob.contentType()->setCharset(contentType->charset());
     cteJob.setData(encodedBody);
     cteJob.exec();
-    cteJob.content()->assemble();
 
     ret->contentTransferEncoding()->setEncoding(cteJob.contentTransferEncoding()->encoding());
-    ret->setEncodedBody(cteJob.content()->encodedBody());
-
-    return ret;
+    auto content = cteJob.takeContent();
+    content->assemble();
+    ret->setEncodedBody(content->encodedBody());
 }
 
-KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *orig,
-                                                             QByteArray encodedBody,
-                                                             Kleo::CryptoMessageFormat format,
-                                                             bool sign,
-                                                             const QByteArray &hashAlgo)
+std::unique_ptr<KMime::Content> MessageComposer::Util::composeHeadersAndBody(std::unique_ptr<KMime::Content> &&orig,
+                                                                             QByteArray encodedBody,
+                                                                             Kleo::CryptoMessageFormat format,
+                                                                             bool sign,
+                                                                             const QByteArray &hashAlgo)
 {
-    auto result = new KMime::Content;
+    auto result = std::make_unique<KMime::Content>();
 
     // called should have tested that the signing/encryption failed
     Q_ASSERT(!encodedBody.isEmpty());
 
     if (!(format & Kleo::InlineOpenPGPFormat)) { // make a MIME message
         qCDebug(MESSAGECOMPOSER_LOG) << "making MIME message, format:" << format;
-        makeToplevelContentType(result, format, sign, hashAlgo);
+        makeToplevelContentType(result.get(), format, sign, hashAlgo);
 
         if (makeMultiMime(format, sign)) { // sign/enc PGPMime, sign SMIME
             const QByteArray boundary = KMime::multiPartBoundary();
@@ -75,9 +74,9 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
             // Build the encapsulated MIME parts.
             // Build a MIME part holding the code information
             // taking the body contents returned in ciphertext.
-            auto code = new KMime::Content;
-            setNestedContentType(code, format, sign);
-            setNestedContentDisposition(code, format, sign);
+            auto code = std::make_unique<KMime::Content>();
+            setNestedContentType(code.get(), format, sign);
+            setNestedContentDisposition(code.get(), format, sign);
 
             if (sign) { // sign PGPMime, sign SMIME
                 if (format & Kleo::AnySMIME) { // sign SMIME
@@ -85,24 +84,24 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
                     ct->setEncoding(KMime::Headers::CEbase64);
                     code->setBody(encodedBody);
                 } else { // sign PGPMmime
-                    setBodyAndCTE(encodedBody, orig->contentType(), code);
+                    setBodyAndCTE(encodedBody, orig->contentType(), code.get());
                 }
-                result->appendContent(orig);
-                result->appendContent(code);
+                result->appendContent(std::move(orig));
+                result->appendContent(std::move(code));
             } else { // enc PGPMime
-                setBodyAndCTE(encodedBody, orig->contentType(), code);
+                setBodyAndCTE(encodedBody, orig->contentType(), code.get());
 
                 // Build a MIME part holding the version information
                 // taking the body contents returned in
                 // structuring.data.bodyTextVersion.
-                auto vers = new KMime::Content;
+                auto vers = std::make_unique<KMime::Content>();
                 vers->contentType()->setMimeType("application/pgp-encrypted");
                 vers->contentDisposition()->setDisposition(KMime::Headers::CDattachment);
                 vers->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
                 vers->setBody("Version: 1");
 
-                result->appendContent(vers);
-                result->appendContent(code);
+                result->appendContent(std::move(vers));
+                result->appendContent(std::move(code));
             }
         } else { // enc SMIME, sign/enc SMIMEOpaque
             result->contentTransferEncoding()->setEncoding(KMime::Headers::CEbase64);
@@ -120,7 +119,7 @@ KMime::Content *MessageComposer::Util::composeHeadersAndBody(KMime::Content *ori
         result->parse();
 
         // fixing ContentTransferEncoding
-        setBodyAndCTE(encodedBody, orig->contentType(), result);
+        setBodyAndCTE(encodedBody, orig->contentType(), result.get());
     }
     return result;
 }
@@ -246,7 +245,7 @@ QString MessageComposer::Util::cleanedUpHeaderString(const QString &s)
     return res.trimmed();
 }
 
-void MessageComposer::Util::addSendReplyForwardAction(const KMime::Message::Ptr &message, Akonadi::MessageQueueJob *qjob)
+void MessageComposer::Util::addSendReplyForwardAction(const std::shared_ptr<KMime::Message> &message, Akonadi::MessageQueueJob *qjob)
 {
     QList<Akonadi::Item::Id> originalMessageId;
     QList<Akonadi::MessageStatus> linkStatus;
@@ -304,7 +303,7 @@ KMime::Content *MessageComposer::Util::findTypeInMessage(KMime::Content *data, c
         if (mimeType.isEmpty() || subType.isEmpty()) {
             return data;
         }
-        if ((mimeType == data->contentType()->mediaType()) && (subType == data->contentType(false)->subType())) {
+        if ((mimeType == data->contentType()->mediaType()) && (subType == data->contentType(KMime::CreatePolicy::DontCreate)->subType())) {
             return data;
         }
     }
@@ -322,7 +321,7 @@ KMime::Content *MessageComposer::Util::findTypeInMessage(KMime::Content *data, c
     return nullptr;
 }
 
-void MessageComposer::Util::addLinkInformation(const KMime::Message::Ptr &msg, Akonadi::Item::Id id, Akonadi::MessageStatus status)
+void MessageComposer::Util::addLinkInformation(const std::shared_ptr<KMime::Message> &msg, Akonadi::Item::Id id, Akonadi::MessageStatus status)
 {
     Q_ASSERT(status.isReplied() || status.isForwarded() || status.isDeleted());
 
@@ -349,16 +348,16 @@ void MessageComposer::Util::addLinkInformation(const KMime::Message::Ptr &msg, A
         type += QLatin1StringView("forward");
     }
 
-    auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Link-Message"));
+    auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-Link-Message");
     header->fromUnicodeString(message);
     msg->setHeader(std::move(header));
 
-    header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Link-Type"));
+    header = std::make_unique<KMime::Headers::Generic>("X-KMail-Link-Type");
     header->fromUnicodeString(type);
     msg->setHeader(std::move(header));
 }
 
-bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, QList<Akonadi::Item::Id> &id, QList<Akonadi::MessageStatus> &status)
+bool MessageComposer::Util::getLinkInformation(const std::shared_ptr<KMime::Message> &msg, QList<Akonadi::Item::Id> &id, QList<Akonadi::MessageStatus> &status)
 {
     auto hrdLinkMsg = msg->headerByType("X-KMail-Link-Message");
     auto hrdLinkType = msg->headerByType("X-KMail-Link-Type");
@@ -390,17 +389,17 @@ bool MessageComposer::Util::getLinkInformation(const KMime::Message::Ptr &msg, Q
 bool MessageComposer::Util::isStandaloneMessage(const Akonadi::Item &item)
 {
     // standalone message have a valid payload, but are not, themselves valid items
-    return item.hasPayload<KMime::Message::Ptr>() && !item.isValid();
+    return item.hasPayload<std::shared_ptr<KMime::Message>>() && !item.isValid();
 }
 
-KMime::Message::Ptr MessageComposer::Util::message(const Akonadi::Item &item)
+std::shared_ptr<KMime::Message> MessageComposer::Util::message(const Akonadi::Item &item)
 {
-    if (!item.hasPayload<KMime::Message::Ptr>()) {
+    if (!item.hasPayload<std::shared_ptr<KMime::Message>>()) {
         qCWarning(MESSAGECOMPOSER_LOG) << "Payload is not a MessagePtr!";
         return {};
     }
 
-    return item.payload<KMime::Message::Ptr>();
+    return item.payload<std::shared_ptr<KMime::Message>>();
 }
 
 bool MessageComposer::Util::hasMissingAttachments(const QStringList &attachmentKeywords, QTextDocument *doc, const QString &subj)
@@ -462,10 +461,10 @@ QStringList MessageComposer::Util::cleanUpEmailListAndEncoding(const QStringList
     return cleanEmailList(encodeIdn(emails));
 }
 
-void MessageComposer::Util::addCustomHeaders(const KMime::Message::Ptr &message, const QMap<QByteArray, QString> &custom)
+void MessageComposer::Util::addCustomHeaders(const std::shared_ptr<KMime::Message> &message, const QMap<QByteArray, QString> &custom)
 {
     for (const auto &[key, value] : custom.asKeyValueRange()) {
-        auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic(key.constData()));
+        auto header = std::make_unique<KMime::Headers::Generic>(key.constData());
         header->fromUnicodeString(value);
         message->setHeader(std::move(header));
     }
