@@ -133,9 +133,21 @@ View::View(Widget *pParent)
 
     connect(selectionModel(), &QItemSelectionModel::selectionChanged, this, &View::slotSelectionChanged, Qt::UniqueConnection);
 
-    // as in KDE3, when a root-item of a message thread is expanded, expand all children
     connect(this, &View::expanded, this, [this](const QModelIndex &index) {
+        // as in KDE3, when a root-item of a message thread is expanded, expand all children
         d->expandFullThread(index);
+
+        Item *it = static_cast<Item *>(index.internalPointer());
+        if (it && (it->type() == Item::Message)) {
+            d->mWidget->viewMessageExpanded(static_cast<MessageItem *>(it));
+        }
+    });
+
+    connect(this, &View::collapsed, this, [this](const QModelIndex &index) {
+        Item *it = static_cast<Item *>(index.internalPointer());
+        if (it && (it->type() == Item::Message)) {
+            d->mWidget->viewMessageCollapsed(static_cast<MessageItem *>(it));
+        }
     });
 }
 
@@ -1666,7 +1678,7 @@ void View::markMessageItemsAsAboutToBeRemoved(const QList<MessageItem *> &items,
     // What happens to the selection is generally an untrackable big mess.
     // Several components and entities are involved.
 
-    // Qutie tries to apply some kind of internal logic in order to keep
+    // Qt tries to apply some kind of internal logic in order to keep
     // "something" selected and "something" (else) to be current.
     // The results sometimes appear to depend on the current moon phase.
 
@@ -1686,7 +1698,7 @@ void View::markMessageItemsAsAboutToBeRemoved(const QList<MessageItem *> &items,
 
     // Add the fact that the operations are asynchronous: deletion will start
     // a job, do some event loop processing and then complete the work at a later time.
-    // The Qutie views also tend to accumulate the changes and perform them
+    // The Qt views also tend to accumulate the changes and perform them
     // all at once at the latest possible stage.
 
     // A radical approach is needed: we FIRST deal with the selection
