@@ -54,13 +54,14 @@ public:
 
     [[nodiscard]] Akonadi::Item::List selectionAsItems() const;
     [[nodiscard]] Akonadi::Item itemForRow(int row) const;
-    [[nodiscard]] KMime::Message::Ptr messageForRow(int row) const;
+    [[nodiscard]] std::shared_ptr<KMime::Message> messageForRow(int row) const;
 
     Widget *const q;
 
     int mLastSelectedMessage = -1;
     KXMLGUIClient *mXmlGuiClient = nullptr;
     QModelIndex mGroupHeaderItemIndex;
+    QIcon mDefaultCollectionIcon;
 };
 } // namespace MessageList
 
@@ -71,13 +72,21 @@ MessageList::Widget::Widget(QWidget *parent)
     : Core::Widget(parent)
     , d(new WidgetPrivate(this))
 {
-    // Init it.
-    (void)Core::TagManager::self();
     connect(Core::TagManager::self(), &Core::TagManager::tagsFetched, this, &MessageList::Widget::slotTagsFetched);
 }
 
 MessageList::Widget::~Widget() = default;
 
+QIcon MessageList::Widget::defaultCollectionIcon() const
+{
+    return d->mDefaultCollectionIcon;
+}
+
+void MessageList::Widget::setDefaultCollectionIcon(const QIcon &icon)
+{
+    d->mDefaultCollectionIcon = icon;
+}
+
 void MessageList::Widget::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
 {
     d->mXmlGuiClient = xmlGuiClient;
@@ -89,7 +98,7 @@ bool MessageList::Widget::canAcceptDrag(const QDropEvent *e)
         return false;
     }
 
-    Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
+    const Collection::List collections = static_cast<const MessageList::StorageModel *>(storageModel())->displayedCollections();
     if (collections.size() != 1) {
         return false; // no folder here or too many (in case we can't decide where the drop will end)
     }
@@ -277,6 +286,22 @@ void MessageList::Widget::viewSelectionChanged()
     }
 }
 
+void MessageList::Widget::viewMessageExpanded(Core::MessageItem *msg)
+{
+    if (msg && msg->isValid()) {
+        const int row = msg->currentModelIndexRow();
+        Q_EMIT messageExpanded(d->itemForRow(row));
+    }
+}
+
+void MessageList::Widget::viewMessageCollapsed(Core::MessageItem *msg)
+{
+    if (msg && msg->isValid()) {
+        const int row = msg->currentModelIndexRow();
+        Q_EMIT messageCollapsed(d->itemForRow(row));
+    }
+}
+
 void MessageList::Widget::viewMessageListContextPopupRequest(const QList<MessageList::Core::MessageItem *> &selectedItems, const QPoint &globalPos)
 {
     Q_UNUSED(selectedItems)
@@ -514,7 +539,7 @@ Akonadi::Item MessageList::Widget::WidgetPrivate::itemForRow(int row) const
     return static_cast<const MessageList::StorageModel *>(q->storageModel())->itemForRow(row);
 }
 
-KMime::Message::Ptr MessageList::Widget::WidgetPrivate::messageForRow(int row) const
+std::shared_ptr<KMime::Message> MessageList::Widget::WidgetPrivate::messageForRow(int row) const
 {
     return static_cast<const MessageList::StorageModel *>(q->storageModel())->messageForRow(row);
 }
@@ -530,7 +555,7 @@ Akonadi::Item MessageList::Widget::currentItem() const
     return d->itemForRow(mi->currentModelIndexRow());
 }
 
-KMime::Message::Ptr MessageList::Widget::currentMessage() const
+std::shared_ptr<KMime::Message> MessageList::Widget::currentMessage() const
 {
     Core::MessageItem *mi = view()->currentMessageItem();
 
@@ -541,9 +566,9 @@ KMime::Message::Ptr MessageList::Widget::currentMessage() const
     return d->messageForRow(mi->currentModelIndexRow());
 }
 
-QList<KMime::Message::Ptr> MessageList::Widget::selectionAsMessageList(bool includeCollapsedChildren) const
+QList<std::shared_ptr<KMime::Message>> MessageList::Widget::selectionAsMessageList(bool includeCollapsedChildren) const
 {
-    QList<KMime::Message::Ptr> lstMiPtr;
+    QList<std::shared_ptr<KMime::Message>> lstMiPtr;
     const QList<Core::MessageItem *> lstMi = view()->selectionAsMessageItemList(includeCollapsedChildren);
     if (lstMi.isEmpty()) {
         return lstMiPtr;
