@@ -1,18 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
 #include "messageviewer_export.h"
-#include <QObject>
+#include <QMetaType>
 class QDebug;
 namespace MessageViewer
 {
-/**
- * @brief The OpenWithUrlInfo class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class MessageViewer::OpenWithUrlInfo
+ * \inmodule MessageViewer
+ * \inheaderfile MessageViewer/OpenWithUrlInfo
+ * \brief The OpenWithUrlInfo class
+ * \author Laurent Montel <montel@kde.org>
  */
 class MESSAGEVIEWER_EXPORT OpenWithUrlInfo
 {
