@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,13 +7,16 @@
 #pragma once
 
 #include "messageviewer_private_export.h"
-#include <QObject>
+#include <QMetaType>
 class QDebug;
 namespace MessageViewer
 {
-/**
- * @brief The RemoteContentInfo class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class MessageViewer::RemoteContentInfo
+ * \inmodule MessageViewer
+ * \inheaderfile MessageViewer/RemoteContentInfo
+ * \brief The RemoteContentInfo class
+ * \author Laurent Montel <montel@kde.org>
  */
 class MESSAGEVIEWER_TESTS_EXPORT RemoteContentInfo
 {
