@@ -1,18 +1,21 @@
 /*
-  SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2021-2026 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 #pragma once
 #include "messageviewer_export.h"
-#include <QObject>
+#include <QMetaType>
 class QDebug;
 namespace MessageViewer
 {
-/**
- * @brief The ScamDetectionInfo class
- * @author Laurent Montel <montel@kde.org>
+/*!
+ * \class MessageViewer::ScamDetectionInfo
+ * \inmodule MessageViewer
+ * \inheaderfile MessageViewer/ScamDetectionInfo
+ * \brief The ScamDetectionInfo class
+ * \author Laurent Montel <montel@kde.org>
  */
 class MESSAGEVIEWER_EXPORT ScamDetectionInfo
 {
@@ -27,19 +30,37 @@ public:
     Q_DECLARE_FLAGS(ScamDetectionFields, ScamDetectionField)
     Q_ENUM(ScamDetectionField)
 
+    /*!
+     */
     ScamDetectionInfo();
+    /*!
+     */
     ~ScamDetectionInfo();
 
+    /*!
+     */
     [[nodiscard]] const QString &domainOrEmail() const;
+    /*!
+     */
     void setDomainOrEmail(const QString &newDomainOrEmail);
 
+    /*!
+     */
     [[nodiscard]] bool enabled() const;
+    /*!
+     */
     void setEnabled(bool newEnabled);
 
+    /*!
+     */
     [[nodiscard]] bool isValid() const;
 
+    /*!
+     */
     [[nodiscard]] ScamDetectionInfo::ScamDetectionFields scamChecks() const;
 
+    /*!
+     */
     [[nodiscard]] bool operator==(const ScamDetectionInfo &other) const;
 
 private:
