@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2005 Till Adam <adam@kde.org>
- * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH LicenseRef-Qt-Commercial-exception-1.0
  */
 
 #include "messageviewer/messageviewerutil.h"
@@ -146,7 +146,7 @@ bool Util::handleUrlWithQDesktopServices(const QUrl &url)
 #endif
 }
 
-bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, QList<QUrl> &urlList)
+bool Util::saveContents(QWidget *parent, const QList<KMime::Content *> &contents, QList<QUrl> &urlList)
 {
     QUrl url;
     QUrl dirUrl;
@@ -429,7 +429,7 @@ bool Util::saveContent(QWidget *parent, const KMime::Content *content, const QUr
     return true;
 }
 
-bool Util::saveAttachments(const KMime::Content::List &contents, QWidget *parent, QList<QUrl> &urlList)
+bool Util::saveAttachments(const QList<KMime::Content *> &contents, QWidget *parent, QList<QUrl> &urlList)
 {
     if (contents.isEmpty()) {
         KMessageBox::information(parent, i18n("Found no attachments to save."));
@@ -443,8 +443,9 @@ QString Util::generateFileNameForExtension(const Akonadi::Item &msgBase, const Q
 {
     QString fileName;
 
-    if (msgBase.hasPayload<KMime::Message::Ptr>()) {
-        fileName = MessageCore::StringUtil::cleanFileName(MessageCore::StringUtil::cleanSubject(msgBase.payload<KMime::Message::Ptr>().data()).trimmed());
+    if (msgBase.hasPayload<std::shared_ptr<KMime::Message>>()) {
+        fileName =
+            MessageCore::StringUtil::cleanFileName(MessageCore::StringUtil::cleanSubject(msgBase.payload<std::shared_ptr<KMime::Message>>().get()).trimmed());
         fileName.remove(u'\"');
     } else {
         fileName = i18n("message");
@@ -512,8 +513,8 @@ bool Util::saveMessageInMboxAndGetUrl(QUrl &url, const Akonadi::Item::List &retr
             return false;
         }
         for (const Akonadi::Item &item : std::as_const(retrievedMsgs)) {
-            if (item.hasPayload<KMime::Message::Ptr>()) {
-                mbox.appendMessage(item.payload<KMime::Message::Ptr>());
+            if (item.hasPayload<std::shared_ptr<KMime::Message>>()) {
+                mbox.appendMessage(item.payload<std::shared_ptr<KMime::Message>>());
             }
         }
 
@@ -567,11 +568,11 @@ bool Util::deleteAttachment(KMime::Content *node)
     QString filename;
     QString name;
     QByteArray mimetype;
-    if (auto cd = node->contentDisposition(false)) {
+    if (auto cd = node->contentDisposition(KMime::CreatePolicy::DontCreate)) {
         filename = cd->filename();
     }
 
-    if (auto ct = node->contentType(false)) {
+    if (auto ct = node->contentType(KMime::CreatePolicy::DontCreate)) {
         name = ct->name();
         mimetype = ct->mimeType();
     }
@@ -583,12 +584,12 @@ bool Util::deleteAttachment(KMime::Content *node)
 
     // text/plain part:
     const auto newName = i18nc("Argument is the original name of the deleted attachment", "Deleted: %1", name);
-    auto deletePart = new KMime::Content(parentNode);
-    auto deleteCt = deletePart->contentType(true);
+    auto deletePart = std::make_unique<KMime::Content>();
+    auto deleteCt = deletePart->contentType(KMime::CreatePolicy::Create);
     deleteCt->setMimeType("text/x-moz-deleted");
     deleteCt->setName(newName);
-    deletePart->contentDisposition(true)->setDisposition(KMime::Headers::CDattachment);
-    deletePart->contentDisposition(false)->setFilename(newName);
+    deletePart->contentDisposition(KMime::CreatePolicy::Create)->setDisposition(KMime::Headers::CDattachment);
+    deletePart->contentDisposition(KMime::CreatePolicy::DontCreate)->setFilename(newName);
 
     deleteCt->setCharset("utf-8");
     deletePart->contentTransferEncoding()->setEncoding(KMime::Headers::CEquPr);
@@ -599,14 +600,14 @@ bool Util::deleteAttachment(KMime::Content *node)
     bodyMessage += ("\nfilename=\"") + filename.toUtf8() + "\"";
     deletePart->setBody(bodyMessage);
     parentNode->takeContent(node);
-    parentNode->appendContent(deletePart);
+    parentNode->appendContent(std::move(deletePart));
 
     parentNode->assemble();
 
     return true;
 }
 
-int Util::deleteAttachments(const KMime::Content::List &nodes)
+int Util::deleteAttachments(const QList<KMime::Content *> &nodes)
 {
     int updatedCount = 0;
     for (const auto node : nodes) {
