@@ -340,11 +340,11 @@ KMMsgEncryptionState NodeHelper::overallEncryptionState(KMime::Content *node) co
     }
 
     KMime::Content *parent = node->parent();
-    auto contents = parent ? parent->contents() : KMime::Content::List();
+    auto contents = parent ? parent->contents() : QList<KMime::Content *>();
     if (contents.isEmpty()) {
         contents.append(node);
     }
-    int i = contents.indexOf(const_cast<KMime::Content *>(node));
+    int i = contents.indexOf(node);
     if (i < 0) {
         return myState;
     }
@@ -401,11 +401,11 @@ KMMsgSignatureState NodeHelper::overallSignatureState(KMime::Content *node) cons
     }
 
     KMime::Content *parent = node->parent();
-    auto contents = parent ? parent->contents() : KMime::Content::List();
+    auto contents = parent ? parent->contents() : QList<KMime::Content *>();
     if (contents.isEmpty()) {
         contents.append(node);
     }
-    int i = contents.indexOf(const_cast<KMime::Content *>(node));
+    int i = contents.indexOf(node);
     if (i < 0) { // Be safe
         return myState;
     }
@@ -521,7 +521,7 @@ QSharedPointer<KMime::Headers::Generics::AddressList> NodeHelper::mailHeaderAsAd
         return nullptr;
     }
     QSharedPointer<KMime::Headers::Generics::AddressList> addressList(new KMime::Headers::Generics::AddressList());
-    addressList->from7BitString(hrd->as7BitString(false));
+    addressList->from7BitString(hrd->as7BitString());
     return addressList;
 }
 
@@ -530,7 +530,7 @@ void NodeHelper::clearOverrideHeaders()
     mHeaderOverwrite.clear();
 }
 
-void NodeHelper::registerOverrideHeader(KMime::Content *message, MessagePart::Ptr part)
+void NodeHelper::registerOverrideHeader(const KMime::Content *message, MessagePart::Ptr part)
 {
     if (!mHeaderOverwrite.contains(message)) {
         mHeaderOverwrite[message] = QList<MessagePart::Ptr>();
@@ -538,7 +538,7 @@ void NodeHelper::registerOverrideHeader(KMime::Content *message, MessagePart::Pt
     mHeaderOverwrite[message].append(part);
 }
 
-QDateTime NodeHelper::dateHeader(KMime::Content *message) const
+QDateTime NodeHelper::dateHeader(const KMime::Content *message) const
 {
     const auto dateHeader = mailHeaderAsBase("date", message);
     if (dateHeader != nullptr) {
@@ -586,9 +586,12 @@ QByteArray NodeHelper::codecName(const KMime::Content *node) const
 
 QString NodeHelper::fileName(const KMime::Content *node)
 {
-    QString name = const_cast<KMime::Content *>(node)->contentDisposition()->filename();
-    if (name.isEmpty()) {
-        name = const_cast<KMime::Content *>(node)->contentType()->name();
+    QString name;
+    if (auto cd = node->contentDisposition(); cd) {
+        name = cd->filename();
+    }
+    if (auto ct = node->contentType(); name.isEmpty() && ct) {
+        name = ct->name();
     }
 
     name = name.trimmed();
@@ -596,7 +599,7 @@ QString NodeHelper::fileName(const KMime::Content *node)
 }
 
 // FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalBodyPartMemento replacement
-Interface::BodyPartMemento *NodeHelper::bodyPartMemento(KMime::Content *node, const QByteArray &which) const
+Interface::BodyPartMemento *NodeHelper::bodyPartMemento(const KMime::Content *node, const QByteArray &which) const
 {
     const QMap<QString, QMap<QByteArray, Interface::BodyPartMemento *>>::const_iterator nit = mBodyPartMementoMap.find(persistentIndex(node));
     if (nit == mBodyPartMementoMap.end()) {
@@ -607,7 +610,7 @@ Interface::BodyPartMemento *NodeHelper::bodyPartMemento(KMime::Content *node, co
 }
 
 // FIXME(Andras) review it (by Marc?) to see if I got it right. This is supposed to be the partNode::internalSetBodyPartMemento replacement
-void NodeHelper::setBodyPartMemento(KMime::Content *node, const QByteArray &which, Interface::BodyPartMemento *memento)
+void NodeHelper::setBodyPartMemento(const KMime::Content *node, const QByteArray &which, Interface::BodyPartMemento *memento)
 {
     QMap<QByteArray, Interface::BodyPartMemento *> &mementos = mBodyPartMementoMap[persistentIndex(node)];
 
@@ -741,21 +744,21 @@ QString NodeHelper::asHREF(const KMime::Content *node) const
     return u"attachment:%1"_s.arg(persistentIndex(node));
 }
 
-KMime::Content *NodeHelper::fromHREF(const KMime::Message::Ptr &mMessage, const QUrl &url) const
+KMime::Content *NodeHelper::fromHREF(const std::shared_ptr<KMime::Message> &mMessage, const QUrl &url) const
 {
     if (url.isEmpty()) {
-        return mMessage.data();
+        return mMessage.get();
     }
 
     if (!url.isLocalFile()) {
-        return contentFromIndex(mMessage.data(), url.adjusted(QUrl::StripTrailingSlash).path());
+        return contentFromIndex(mMessage.get(), url.adjusted(QUrl::StripTrailingSlash).path());
     } else {
         const QString path = url.toLocalFile();
         const QString extractedPath = extractAttachmentIndex(path);
         if (!extractedPath.isEmpty()) {
-            return contentFromIndex(mMessage.data(), extractedPath);
+            return contentFromIndex(mMessage.get(), extractedPath);
         }
-        return mMessage.data();
+        return mMessage.get();
     }
 }
 
@@ -829,13 +832,14 @@ QString NodeHelper::fromAsString(const KMime::Content *node) const
     return {};
 }
 
-void NodeHelper::attachExtraContent(KMime::Content *topLevelNode, KMime::Content *content)
+void NodeHelper::attachExtraContent(const KMime::Content *topLevelNode, std::unique_ptr<KMime::Content> &&content)
 {
-    qCDebug(MIMETREEPARSER_LOG) << "mExtraContents added for" << topLevelNode << " extra content: " << content;
-    mExtraContents[topLevelNode].append(content);
+    qCDebug(MIMETREEPARSER_LOG) << "mExtraContents added for" << topLevelNode << " extra content: " << content.get();
+    Q_ASSERT(content);
+    mExtraContents[topLevelNode].append(content.release());
 }
 
-void NodeHelper::cleanExtraContent(KMime::Content *topLevelNode)
+void NodeHelper::cleanExtraContent(const KMime::Content *topLevelNode)
 {
     qCDebug(MIMETREEPARSER_LOG) << "remove all extraContents for" << topLevelNode;
     mExtraContents[topLevelNode].clear();
@@ -860,10 +864,10 @@ void NodeHelper::mergeExtraNodes(KMime::Content *node)
                                           << extra << extra->encodedContent();
             continue;
         }
-        auto c = new KMime::Content(node);
+        auto c = std::make_unique<KMime::Content>();
         c->setContent(extra->encodedContent());
         c->parse();
-        node->appendContent(c);
+        node->appendContent(std::move(c));
     }
 
     const auto contents{node->contents()};
@@ -919,7 +923,7 @@ KMime::Message *NodeHelper::messageWithExtraContent(KMime::Content *topLevelNode
     return m;
 }
 
-KMime::Content *NodeHelper::decryptedNodeForContent(KMime::Content *content) const
+KMime::Content *NodeHelper::decryptedNodeForContent(const KMime::Content *content) const
 {
     const QList<KMime::Content *> xc = extraContents(content);
     if (!xc.empty()) {
@@ -932,15 +936,15 @@ KMime::Content *NodeHelper::decryptedNodeForContent(KMime::Content *content) con
     return nullptr;
 }
 
-bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &resultingData, bool addHeaders, int recursionLevel)
+bool NodeHelper::unencryptedMessage_helper(const KMime::Content *node, QByteArray &resultingData, bool addHeaders, int recursionLevel)
 {
     bool returnValue = false;
     if (node) {
-        KMime::Content *curNode = node;
+        const KMime::Content *curNode = node;
         KMime::Content *decryptedNode = nullptr;
-        const QByteArray type = node->contentType(false) ? QByteArray(node->contentType(false)->mediaType()).toLower() : "text";
-        const QByteArray subType = node->contentType(false) ? node->contentType(false)->subType().toLower() : "plain";
-        const bool isMultipart = node->contentType(false) && node->contentType(false)->isMultipart();
+        const QByteArray type = node->contentType() ? node->contentType()->mediaType().toLower() : "text";
+        const QByteArray subType = node->contentType() ? node->contentType()->subType().toLower() : "plain";
+        const bool isMultipart = node->contentType() && node->contentType()->isMultipart();
         bool isSignature = false;
 
         qCDebug(MIMETREEPARSER_LOG) << "(" << recursionLevel << ") Looking at" << type << "/" << subType;
@@ -973,23 +977,23 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
             KMime::Content headers;
             headers.setHead(curNode->head());
             headers.parse();
-            if (auto ct = decryptedNode->contentType(false)) {
-                headers.contentType()->from7BitString(ct->as7BitString(false));
+            if (auto ct = decryptedNode->contentType(KMime::CreatePolicy::DontCreate)) {
+                headers.contentType()->from7BitString(ct->as7BitString());
             } else {
                 headers.removeHeader<KMime::Headers::ContentType>();
             }
-            if (auto ct = decryptedNode->contentTransferEncoding(false)) {
-                headers.contentTransferEncoding()->from7BitString(ct->as7BitString(false));
+            if (auto ct = decryptedNode->contentTransferEncoding(KMime::CreatePolicy::DontCreate)) {
+                headers.contentTransferEncoding()->from7BitString(ct->as7BitString());
             } else {
                 headers.removeHeader<KMime::Headers::ContentTransferEncoding>();
             }
-            if (auto cd = decryptedNode->contentDisposition(false)) {
-                headers.contentDisposition()->from7BitString(cd->as7BitString(false));
+            if (auto cd = decryptedNode->contentDisposition(KMime::CreatePolicy::DontCreate)) {
+                headers.contentDisposition()->from7BitString(cd->as7BitString());
             } else {
                 headers.removeHeader<KMime::Headers::ContentDisposition>();
             }
-            if (auto cd = decryptedNode->contentDescription(false)) {
-                headers.contentDescription()->from7BitString(cd->as7BitString(false));
+            if (auto cd = decryptedNode->contentDescription(KMime::CreatePolicy::DontCreate)) {
+                headers.contentDescription()->from7BitString(cd->as7BitString());
             } else {
                 headers.removeHeader<KMime::Headers::ContentDescription>();
             }
@@ -1017,7 +1021,7 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
             }
             const QByteArray boundary = curNode->contentType()->boundary();
             const auto contents = curNode->contents();
-            for (KMime::Content *child : contents) {
+            for (const KMime::Content *child : contents) {
                 resultingData += "\n--" + boundary + '\n';
                 const bool changed = unencryptedMessage_helper(child, resultingData, true, recursionLevel + 1);
                 if (changed) {
@@ -1032,7 +1036,7 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
                 resultingData += curNode->head() + '\n';
             }
 
-            returnValue = unencryptedMessage_helper(curNode->bodyAsMessage().data(), resultingData, true, recursionLevel + 1);
+            returnValue = unencryptedMessage_helper(curNode->bodyAsMessage().get(), resultingData, true, recursionLevel + 1);
         } else {
             qCDebug(MIMETREEPARSER_LOG) << "Current node is an ordinary leaf node, adding it as-is.";
             if (addHeaders) {
@@ -1047,10 +1051,10 @@ bool NodeHelper::unencryptedMessage_helper(KMime::Content *node, QByteArray &res
     return returnValue;
 }
 
-KMime::Message::Ptr NodeHelper::unencryptedMessage(const KMime::Message::Ptr &originalMessage)
+std::shared_ptr<KMime::Message> NodeHelper::unencryptedMessage(const std::shared_ptr<KMime::Message> &originalMessage)
 {
     QByteArray resultingData;
-    const bool messageChanged = unencryptedMessage_helper(originalMessage.data(), resultingData, true);
+    const bool messageChanged = unencryptedMessage_helper(originalMessage.get(), resultingData, true);
     if (messageChanged) {
 #if 0
         qCDebug(MIMETREEPARSER_LOG) << "Resulting data is:" << resultingData;
@@ -1059,7 +1063,7 @@ KMime::Message::Ptr NodeHelper::unencryptedMessage(const KMime::Message::Ptr &or
         bla.write(resultingData);
         bla.close();
 #endif
-        KMime::Message::Ptr newMessage(new KMime::Message);
+        std::shared_ptr<KMime::Message> newMessage(new KMime::Message);
         newMessage->setContent(resultingData);
         newMessage->parse();
         return newMessage;
