@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2026 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -47,7 +47,7 @@ Q_DECL_CONSTEXPR inline int pipeTimeout()
 
 using namespace TemplateParser;
 
-TemplateParserJobPrivate::TemplateParserJobPrivate(const KMime::Message::Ptr &amsg, const TemplateParserJob::Mode amode)
+TemplateParserJobPrivate::TemplateParserJobPrivate(const std::shared_ptr<KMime::Message> &amsg, const TemplateParserJob::Mode amode)
     : mMsg(amsg)
     , mMode(amode)
 {
@@ -70,7 +70,7 @@ void TemplateParserJobPrivate::setAllowDecryption(const bool allowDecryption)
     mEmptySource->setDecryptMessage(mAllowDecryption);
 }
 
-TemplateParserJob::TemplateParserJob(const KMime::Message::Ptr &amsg, const Mode amode, QObject *parent)
+TemplateParserJob::TemplateParserJob(const std::shared_ptr<KMime::Message> &amsg, const Mode amode, QObject *parent)
     : QObject(parent)
     , d(new TemplateParserJobPrivate(amsg, amode))
 {
@@ -137,7 +137,7 @@ int TemplateParserJob::parseQuotes(const QString &prefix, const QString &str, QS
     return len;
 }
 
-void TemplateParserJob::process(const KMime::Message::Ptr &aorig_msg, qint64 afolder)
+void TemplateParserJob::process(const std::shared_ptr<KMime::Message> &aorig_msg, qint64 afolder)
 {
     if (aorig_msg == nullptr) {
         qCDebug(TEMPLATEPARSER_LOG) << "aorig_msg == 0!";
@@ -157,7 +157,7 @@ void TemplateParserJob::process(const KMime::Message::Ptr &aorig_msg, qint64 afo
     processWithTemplate(tmpl);
 }
 
-void TemplateParserJob::process(const QString &tmplName, const KMime::Message::Ptr &aorig_msg, qint64 afolder)
+void TemplateParserJob::process(const QString &tmplName, const std::shared_ptr<KMime::Message> &aorig_msg, qint64 afolder)
 {
     d->mForceCursorPosition = false;
     d->mOrigMsg = aorig_msg;
@@ -166,7 +166,7 @@ void TemplateParserJob::process(const QString &tmplName, const KMime::Message::P
     processWithTemplate(tmpl);
 }
 
-void TemplateParserJob::processWithIdentity(uint uoid, const KMime::Message::Ptr &aorig_msg, qint64 afolder)
+void TemplateParserJob::processWithIdentity(uint uoid, const std::shared_ptr<KMime::Message> &aorig_msg, qint64 afolder)
 {
     d->mIdentity = uoid;
     process(aorig_msg, afolder);
@@ -203,7 +203,7 @@ static MimeTreeParser::MessagePart::Ptr toplevelTextNode(MimeTreeParser::Message
 
 void TemplateParserJob::processWithTemplate(const QString &tmpl)
 {
-    d->mOtp->parseObjectTree(d->mOrigMsg.data());
+    d->mOtp->parseObjectTree(d->mOrigMsg.get());
 
     const auto mp = toplevelTextNode(d->mOtp->parsedPart());
     if (!mp) {
@@ -280,7 +280,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const int len = parseQuotes(u"DICTIONARYLANGUAGE="_s, cmd, q);
                 i += len;
                 if (!q.isEmpty()) {
-                    auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-Dictionary"));
+                    auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-Dictionary");
                     header->fromUnicodeString(q);
                     d->mMsg->setHeader(std::move(header));
                 }
@@ -441,7 +441,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 const QString htmlStr = pipe(pipe_cmd, htmlBody);
                 htmlBody = htmlStr;
 
-                auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-CursorPos"));
+                auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(0));
                 d->mMsg->setHeader(std::move(header));
             } else if (cmd.startsWith(QLatin1StringView("TEXT"))) {
@@ -955,7 +955,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 i += strlen("CLEAR");
                 plainBody.clear();
                 htmlBody.clear();
-                auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-CursorPos"));
+                auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(0));
                 d->mMsg->setHeader(std::move(header));
             } else if (cmd.startsWith(QLatin1StringView("DEBUGOFF"))) {
@@ -973,7 +973,7 @@ void TemplateParserJob::slotExtractInfoDone(const TemplateParserExtractHtmlInfoR
                 qCDebug(TEMPLATEPARSER_LOG) << "Command: CURSOR";
                 int oldI = i;
                 i += strlen("CURSOR");
-                auto header = std::unique_ptr<KMime::Headers::Generic>(new KMime::Headers::Generic("X-KMail-CursorPos"));
+                auto header = std::make_unique<KMime::Headers::Generic>("X-KMail-CursorPos");
                 header->fromUnicodeString(QString::number(plainBody.length()));
                 /* if template is:
                  *  FOOBAR
@@ -1078,7 +1078,7 @@ QString TemplateParserJob::getHtmlSignature() const
 void TemplateParserJob::addProcessedBodyToMessage(const QString &plainBody, const QString &htmlBody) const
 {
     MessageCore::ImageCollector ic;
-    ic.collectImagesFrom(d->mOrigMsg.data());
+    ic.collectImagesFrom(d->mOrigMsg.get());
 
     // Now, delete the old content and set the new content, which
     // is either only the new text or the new text with some attachments.
@@ -1099,79 +1099,80 @@ void TemplateParserJob::addProcessedBodyToMessage(const QString &plainBody, cons
     d->mMsg->removeHeader<KMime::Headers::ContentType>(); // to get rid of old boundary
 
     // const QByteArray boundary = KMime::multiPartBoundary();
-    KMime::Content *const mainTextPart = htmlBody.isEmpty() ? createPlainPartContent(plainBody) : createMultipartAlternativeContent(plainBody, htmlBody);
-    mainTextPart->assemble();
+    auto mainPart = htmlBody.isEmpty() ? createPlainPartContent(plainBody) : createMultipartAlternativeContent(plainBody, htmlBody);
+    mainPart->assemble();
 
-    KMime::Content *textPart = mainTextPart;
     if (!ic.images().empty()) {
-        textPart = createMultipartRelated(ic, mainTextPart);
-        textPart->assemble();
+        mainPart = createMultipartRelated(ic, std::move(mainPart));
+        mainPart->assemble();
     }
 
     // If we have some attachments, create a multipart/mixed mail and
     // add the normal body as well as the attachments
-    KMime::Content *mainPart = textPart;
     if (d->mMode == Forward) {
         auto attachments = d->mOrigMsg->attachments();
         attachments += d->mOtp->nodeHelper()->attachmentsOfExtraContents();
         if (!attachments.isEmpty()) {
-            mainPart = createMultipartMixed(attachments, textPart);
+            mainPart = createMultipartMixed(attachments, std::move(mainPart));
             mainPart->assemble();
         }
     }
 
     d->mMsg->setBody(mainPart->encodedBody());
-    d->mMsg->setHeader(mainPart->contentType());
-    d->mMsg->setHeader(mainPart->contentTransferEncoding());
+    d->mMsg->contentType(KMime::CreatePolicy::Create)->from7BitString(mainPart->contentType()->as7BitString());
+    d->mMsg->contentTransferEncoding(KMime::CreatePolicy::Create)->from7BitString(mainPart->contentTransferEncoding()->as7BitString());
     d->mMsg->assemble();
     d->mMsg->parse();
 }
 
-KMime::Content *TemplateParserJob::createMultipartMixed(const QList<KMime::Content *> &attachments, KMime::Content *textPart) const
+std::unique_ptr<KMime::Content> TemplateParserJob::createMultipartMixed(const QList<KMime::Content *> &attachments,
+                                                                        std::unique_ptr<KMime::Content> &&textPart) const
 {
-    auto mixedPart = new KMime::Content(d->mMsg.data());
+    auto mixedPart = std::make_unique<KMime::Content>();
     const QByteArray boundary = KMime::multiPartBoundary();
     auto contentType = mixedPart->contentType();
     contentType->setMimeType("multipart/mixed");
     contentType->setBoundary(boundary);
     mixedPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
-    mixedPart->appendContent(textPart);
+    mixedPart->appendContent(std::move(textPart));
 
     int attachmentNumber = 1;
-    for (KMime::Content *attachment : attachments) {
-        mixedPart->appendContent(attachment);
+    for (const KMime::Content *attachment : attachments) {
+        auto newAtt = attachment->clone();
         // If the content type has no name or filename parameter, add one, since otherwise the name
         // would be empty in the attachment view of the composer, which looks confusing
-        if (auto ct = attachment->contentType(false)) {
+        if (auto ct = newAtt->contentType(KMime::CreatePolicy::DontCreate)) {
             if (!ct->hasParameter("name") && !ct->hasParameter("filename")) {
                 ct->setParameter(QByteArrayLiteral("name"), i18nc("@item:intext", "Attachment %1", attachmentNumber));
             }
         }
+        mixedPart->appendContent(std::move(newAtt));
         ++attachmentNumber;
     }
     return mixedPart;
 }
 
-KMime::Content *TemplateParserJob::createMultipartRelated(const MessageCore::ImageCollector &ic, KMime::Content *mainTextPart) const
+std::unique_ptr<KMime::Content> TemplateParserJob::createMultipartRelated(const MessageCore::ImageCollector &ic,
+                                                                          std::unique_ptr<KMime::Content> &&mainTextPart) const
 {
-    auto relatedPart = new KMime::Content(d->mMsg.data());
+    auto relatedPart = std::make_unique<KMime::Content>();
     const QByteArray boundary = KMime::multiPartBoundary();
     auto contentType = relatedPart->contentType();
     contentType->setMimeType("multipart/related");
     contentType->setBoundary(boundary);
     relatedPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
-    relatedPart->appendContent(mainTextPart);
-    for (KMime::Content *image : ic.images()) {
+    relatedPart->appendContent(std::move(mainTextPart));
+    for (const KMime::Content *image : ic.images()) {
         qCWarning(TEMPLATEPARSER_LOG) << "Adding" << image->contentID() << "as an embedded image";
-        relatedPart->appendContent(image);
+        relatedPart->appendContent(image->clone());
     }
     return relatedPart;
 }
 
-KMime::Content *TemplateParserJob::createPlainPartContent(const QString &plainBody) const
+std::unique_ptr<KMime::Content> TemplateParserJob::createPlainPartContent(const QString &plainBody) const
 {
-    auto textPart = new KMime::Content(d->mMsg.data());
-    auto ct = textPart->contentType(true);
+    auto textPart = std::make_unique<KMime::Content>();
+    auto ct = textPart->contentType(KMime::CreatePolicy::Create);
     ct->setMimeType("text/plain");
     ct->setCharset(QByteArrayLiteral("UTF-8"));
     textPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE8Bit);
@@ -1179,19 +1180,18 @@ KMime::Content *TemplateParserJob::createPlainPartContent(const QString &plainBo
     return textPart;
 }
 
-KMime::Content *TemplateParserJob::createMultipartAlternativeContent(const QString &plainBody, const QString &htmlBody) const
+std::unique_ptr<KMime::Content> TemplateParserJob::createMultipartAlternativeContent(const QString &plainBody, const QString &htmlBody) const
 {
-    auto multipartAlternative = new KMime::Content(d->mMsg.data());
+    auto multipartAlternative = std::make_unique<KMime::Content>();
     multipartAlternative->contentType()->setMimeType("multipart/alternative");
     const QByteArray boundary = KMime::multiPartBoundary();
-    multipartAlternative->contentType(false)->setBoundary(boundary); // Already created
+    multipartAlternative->contentType(KMime::CreatePolicy::DontCreate)->setBoundary(boundary); // Already created
 
-    KMime::Content *textPart = createPlainPartContent(plainBody);
-    multipartAlternative->appendContent(textPart);
+    multipartAlternative->appendContent(createPlainPartContent(plainBody));
 
-    auto htmlPart = std::unique_ptr<KMime::Content>(new KMime::Content(d->mMsg.data()));
-    htmlPart->contentType(true)->setMimeType("text/html");
-    htmlPart->contentType(false)->setCharset(QByteArrayLiteral("UTF-8")); // Already created
+    auto htmlPart = std::make_unique<KMime::Content>();
+    htmlPart->contentType(KMime::CreatePolicy::Create)->setMimeType("text/html");
+    htmlPart->contentType(KMime::CreatePolicy::DontCreate)->setCharset(QByteArrayLiteral("UTF-8")); // Already created
     htmlPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE8Bit);
     htmlPart->fromUnicodeString(htmlBody);
     multipartAlternative->appendContent(std::move(htmlPart));
@@ -1441,7 +1441,7 @@ QString TemplateParserJob::quotedHtmlText(const QString &selection) const
     return content;
 }
 
-uint TemplateParserJob::identityUoid(const KMime::Message::Ptr &msg) const
+uint TemplateParserJob::identityUoid(const std::shared_ptr<KMime::Message> &msg) const
 {
     QString idString;
     if (auto hrd = msg->headerByType("X-KMail-Identity")) {
